%%% Inversion for layered model 
%%% ============================================================

addpath matlab/		% use processing codes from directory matlab/
addpath modeling/	% use modeling codes from this directory

%% Processing parameters can be passed to the various codes by using
%% global structure 'procdata'. 
%% First, set up the initial values of the fields in this structure:

global procdata

procdata_default()

% several other global variables for data exchange between modeling functions 
% and interactive inspection
 
global model modes   

% set up an array of desired HALF-WAVELENGTHS for output (in meters)
% These half-wavelengths are roughly the expected depths of sampling

lambda2 = [ 0.25 : 0.5 : 20 ];	

%% set the FFID number with which you will work

FFID = 143;

%% you will need to perform the following steps with
%% FFID numbers = 143, 153, 163, and 172
%% The data for these FFIDs are provided in directory data/
%% ========================================================================

% 1) load the data into structures 'rec' (records), 'spec' (spectra) 
%	and 'disp' (phase-velocity semblance)
%    Note that this call also returns the .mat file name from which these data
%	are loaded, so that you can save the modeling results in the same file later

[ rec, spec, dispsemb, matfile ] = record_ffid(FFID);

% plot and view the section

figure(1)

plot_ffid1(rec,0.6)		

% plot and view dispersion results, identify the fundamental mode in the plot:

	% set zoom-in parameters for dispersion semblance display

procdata.plot_slwns_range = [ 0, 15.0 ];	% slowness range
procdata.plot_freq_range = [ 0, 0.12 ];		% frequency range (kHz)

% uncomment the following lines to see a plot of dispersion semblance
% This plot will also be shown in the final figure 101

figure(2)

plot_dispersion(dispsemb)

%% Begin modeling and inversion
%% Set up model (columns are depth at bottom, density, P-wave velocity, S-wave velocity, 
%%		P-wave viscosity, S-wave viscosity (don't worry about the last two))

% File name with starting model used when no .mat file for the model are present yet.

procdata.default_model = 'interp/starting_model.txt'; 

% Interactive picking by pick_model() below does not work at present.
% Instead of it, we will adjust the model by varying factors 'scale_V' which scale
% the P- and S-wave velocities in each layer.
% This column should have the same number of rows as in the model: 

scale_V = [	1
		1
		1
		1
		1
		1
	];

% Model phase and group velocities at wavenumbers corresponding to lambda2.
% Return results as fields in structure 'modes': modes.freq, modes.vphase, modes.vgroup

%forward_model( 1, -1, FFID, lambda2, scale_V );  % parameters 1, 0, FFID are the line number,
						% 'vintage number', and 'location number'
						% which we take equal FFID

% Interactive picking (use this instead of the forward_model() call above:

procdata.plot_modes = 'zvs';	% will be plotting (pseudodepth, Vs) plots of wave modes

procdata.plot_Z_range = [ 0, 10 ];	% reduced Z (depth) range for plot
procdata.plot_V_range = [ 0 0.5 ];	% S-wave velocity range to plot

procdata.location_id = 'ffid';	% name of the field used to selecting records for plotting
				% This is needed because we are using 'FFID' in pick_model() below

procdata.plot_modes_num = 3;	% number of modes to plot

pick_model( 1, -1, FFID, lambda2 );	% interactive scaling using mouse buttons and keyboard commands 

%% plot in figure 101 three panels:
%%	1) layered velocity model and modes vs. pseudodepth
%%	2) dispersion semblance on (frequency,slowness) plane
%%	3) phase velocities of three miodes vs. frequency

plot_modes_3panes( modes.freq, modes.vphase, dispsemb, 3, 101 )



