%% Returns 'ick' structure containing automatic (maximum-semblance) picks 
%% from a data record 
%% ===================================================================
%%
%% Parameters:
%%      num - requested FFID or CMP number (depending on the value of 
%%			procdata.data_order)
%% Returns
%%	pick - structure containing the picks, ffid, id value, etc.
%%	param - parameters of display for these picks

function [ pick, param ] = autopick_dispersion(num)

global procdata

  dataset = lower(procdata.data_order);

  % load dispersion spectra from .mat files

  switch dataset
	case 'ffid'
  		[ rec, spec, dispsemb ] = record_ffid(num);

  		pick.number = rec.ffid;
		pick.id = rec.src_stn;
  		pick.line = rec.line;
  		pick.vintage = rec.vintage;

  		if isempty(rec)
			error('Record for num %d is empty', num)
  		elseif isempty(spec)
			error('Spectra for num %d have not been created', num)
 		elseif isempty(dispsemb)
			error('Dispersion semblance for num %d has not been created', num)
  		end

	case 'cmp'

		dataf = filename_dispersion(procdata.line(1),procdata.vintage);

		if exist(dataf)
			load(dataf)	% this should give structure 'dispsemb'
		else
			disp(sprintf('File %s does not exist',dataf))
			return
		end

  		pick.number = dispsemb.ffid;
		pick.id = dispsemb.ffid;
  		pick.line = dispsemb.line;
  		pick.vintage = dispsemb.vintage;
  end

  % store in pick key information from record

  switch dataset
	case 'ffid'

			pick.id = rec.src_stn;

	case 'cmp'

			pick.id = num;
  end

  % output all all points in dispsemb.semb_peak as one segment

  pick.modes_xy = dispsemb.semb_peak(:,1:2);

  pick.modes = [ 1, size(pick.modes_xy,1) ];

  % use standard plotting parameters

  param = param_pick_dispersion();

end

