%% Average mode picks corresponding to the same vintages and ID
%% The resulting averaged modes are written in files interp/interp_id<ID_number>.mat
%%
%% Parameters:
%%      line_list - list of line numbers to perform averaging for

function average_modes(line_list)

global procdata
global avpick param

  procdata.dataset = 'ffid';	% only using ffid-sorted dataset
	
  for line_no=line_list

	procdata.line = line_no;

	% obtain lists of available vintages and IDs

	[ ~, avpick.vint_list, ~, avpick.id_list ] = list_line(line_no);	

	% try one vintage and ID at a time, save each of the averaged picks in a separate file

	for j = 1:length(avpick.vint_list)

  	  avpick.vintage = avpick.vint_list(j);		% vintage to work on

	  procdata.vintage = avpick.vintage;		% this will narrow down file selection in proc_ffids()

	  for k = 1:length(avpick.id_list)

  		avpick.id = avpick.id_list(k);		% ID in avpick.id_list

		avpick.cnt_rec = 0;			% counter for the number of input records

		proc_ffids(@average_modes1)		% collect all data

		% perform averaging

		mean_s = zeros(size(avpick.cnt));

		for k1=1:size(avpick.slwns,1)
		  for i=1:size(avpick.slwns,2)
			ind = find(avpick.slwns(k1,i,:) > 1.0e-8);	% valid readings for this mode and freq

			if ~isempty(ind)
				mean_s(k1,i) = median(avpick.slwns(k1,i,ind));
			end
		  end
		end

		% test plot

		if procdata.plot_aux && avpick.id == 1

%pid = [ pick.id, pick.number, pick.vintage ]

		  for i=1:size(avpick.slwns,2)			% loop over modes

		    figure(avpick.vintage*10+i)
		    hold on

		    for i1=1:size(avpick.slwns,3)		% loop over ffids
			ind = find(avpick.slwns(:,i,i1) > 1.e-8);	% good data

			plot(avpick.f(ind),avpick.slwns(ind,i,i1),'-b')
		    end

		    ind = mean_s(:,i) > 1.0e-8;		% frequencies at which the median is found

		    if ~isempty(ind)
			plot(avpick.f(ind),mean_s(ind,i),'-r')
		    end
		  end

		end

  		%% save the average picks in structure 'pick' in interpretation files
  
 	 	pick = avpick.pick;		% all auxiliary parameters and matrices 'modes' and 'modes_xy'

		pick.id = avpick.id;
		pick.vintage = avpick.vintage;

		[ pick.modes, pick.modes_xy ] = set_segments(avpick.f,mean_s);

%pid = pick.id
%pvint = pick.vintage

%pm = pick.modes 
%pmxy = pick.modes_xy

  		[ ~, fn ] = filename_interp( pick.id, procdata.dataset, pick.vintage );

		% rebuild param structure which for some reason cannot be resaved after loading from Matlab

  		param = param_pick_dispersion();

  		warning off
  		mkdir('interp/');		% create directory in case it is absent
  		warning on

  		if inOctave()
  			save(fn,'-mat7-binary','pick','param');
  		else
  			save(fn,'pick','param');
  		end

	  end	% loop k (id)

	end	% loop vint

  end		% loop line

end

