%% Helper to average_modes():
%%	adds picked modes from ffid or CMP number 'num' to the average picks
%%
%% Parameters:
%%      num - requested FFID or CMP number 

function average_modes1(num)

global procdata
global avpick param

  fn = filename_interp( num, procdata.dataset );

  if exist(fn)
	load(fn)		% this loads 'pick' and 'param' for the given 'num'

	% use only data for correct vintage and ID

	if pick.id ~= avpick.id || pick.vintage ~= avpick.vintage
		return
	end

	% load the automatic picks of dispersion spectra maxima

	[ peak, peak1, freq ] = dispersion_peaks(num);
 
	nmodes = size(pick.modes,1);

	if avpick.cnt_rec == 0

		% init matrix of slownesses for all modes. 
		% Columns are modes, rows are frequencies

		avpick.f = freq;
		avpick.slwns = zeros(length(freq),nmodes,1);	% matrix to store all slowness values
		avpick.cnt = zeros(1,nmodes);	% counts of curves stored for each mode

		avpick.pick = pick;	% get all auxiliary parameters	from first 'pick'	
	end

	avpick.cnt_rec = avpick.cnt_rec + 1;

	% interpolate slownesses for each mode from exact peaks and
	% put them in the big slowness matrix

	for i=1:nmodes
		if pick.modes(i,1) < 1		% no such mode in picks
			continue
		end

		n = pick.modes(i,1):pick.modes(i,2);		% range of rows in pick.modes_xy

		[ p, k ] = interp_peaks( pick.modes_xy(n,:), freq, peak, peak1); 
							%  exact or approximate peaks interpolated into freq array

		avpick.cnt(i) = avpick.cnt(i)+1;	% increment mode counters

		avpick.slwns(k,i,avpick.cnt(i)) = p;	% place values

		% test plot

		if procdata.plot_aux && avpick.id == 1

%pid = [ pick.id, pick.number, pick.vintage ]

			figure(avpick.vintage*10+i)
			hold on

			plot(pick.modes_xy(n,1),pick.modes_xy(n,2),'-k')
			plot(freq(k),p,'-r')
			text(freq(k(end)),p(end),num2str(pick.number))
		end

	end
  end
end

