%% Deletes one or several segments from matrix 'xy_matr'
%% ===========================================================================
%%
%% Parameters:
%%	xy_matr_out, xy_ind_out - data and index matrices to update
%%	segment - array of segment numbers (indeces of the row in xy_ind) to delete. 
%%		If segment=[], or not in range of xy_ind,
%%		no deletion is made
%%
%% Returns:
%%	xy_matr_out, xy_ind_out - updated xy_matr and xy_ind

function [ xy_matr_out, xy_ind_out ] = delete_segment( xy_matr, xy_ind, segment )

	xy_matr_out = xy_matr;
	xy_ind_out = xy_ind;

	if isempty(segment) 		% nothing to do
		return
	end

	% handle the case of multipe segments first

	if length(segment) > 1
		for i=1:length(n)
		  	[ xy_matr_out, xy_ind_out ] = delete_segment(xy_matr_out,xy_ind_out,n(i));
		end

		return
	end

	% here we need to delete exactly one segment

	if segment < 1 || size(xy_ind_out,1) < segment		% nothing to do
		return
	end

	if xy_ind(segment,1) == 0	% segment already empty
		return
	end

	n = xy_ind(segment,2) - xy_ind(segment,1) + 1;		% number of points to drop

	% modify segment indices
		
	for j=1:size(xy_ind_out,1)

		if j == segment

			xy_ind_out(j,1) = 0;
			xy_ind_out(j,2) = 0;

		elseif xy_ind_out(j,1) >= xy_ind(segment,1)	% the segment j was after 'segment'
	
			xy_ind_out(j,:) = xy_ind_out(j,:) - n;
		end
	end

	% remove point from data matrix

	xy_matr_out(xy_ind(segment,1):xy_ind(segment,2),:) = [];
end

