%% Returns distances between two sets of points
%% ---------------------------------------------------------------------
%% Parameters:
%%	xyz1 - column of 1, 2, or 3-dimensional coordinates
%%	xyz2 - column of 1, 2, or 3-dimensional coordinates
%%
%%  Returns:
%%	dist - matrix of distances between the different points in xyz1 and xyz2
%%		Rows of dist correspond to rows in xyz1, and columns of dist
%%		correspond to rows in xyz2
%%	dist - matrix of azimuths of points in xyz2 when looking from points in xyz1
%% =====================================================================

function [ dist, az ] = distance( xyz1, xyz2 )

	n1 = size(xyz1,1);
	n2 = size(xyz2,1);

	dist = zeros(n1,n2);
	az = zeros(n1,n2);

	for j=1:n2
		d = xyz1-xyz2(j,:);
		dist(:,j) = sqrt(sum(d.*d,2));
	end

	if nargout > 1 && size(xyz1,2) > 1		% have (x,y)
	  for j=1:n2
		az(:,j) = atan2(xyz2(j,2)-xyz1(:,2), xyz2(j,1)-xyz1(:,1));	% atan2(y,x)
	  end
	end
end

