%% Extracts geometry information from all .mat files in 'data/'
%% ---------------------------------------------------------------------
%% Parameters:
%%      lineno - line number (can be an array, in which the first element is used)
%%		If this parameter is not specified or equals [] or 0, extracts data from all lines
%%      pattno - pattern number (can be an array, in which the first element is used)
%%		If this parameter is not specified or equals [] or 0, extracts data for all patterns
%%
%%  Returns:
%%      src - source matrix with nine columns:
%%		1) source number;
%%		2) station number;
%%		3) FFID for this source 
%%		4) inline shift from station (skid)
%%		5) crossline shift from station (offset)
%%		6) inline coordinate 
%%		7)-9) three columns of coordinates (north, east, elevation) 
%%      rec - receiver matrix with five columns:
%%		1) surface station number;
%%		2) inline coordinate 
%%		3)-5) three columns of coordinates (north, east, elevation) 
%%	trc - matrix of all traces with 14 columns:
%%		1) line number
%%		2) vintage number
%%		3) pattern number
%%		4) ffid;
%%		5) chan;
%%		6) source station number;
%%		7) receiver station number;
%%		8-10) source coordinates;
%%		11-13) receiver coordinates;
%%		14) flag equal one when the record is good or 0 if it is killed
%% ===============================================================================

function [src, rec, trc ] = extract_geometry( lineno, pattno )

global src111 rec111 trc111 line111 patt111
global procdata

  if nargin < 1
	lineno = 0;
  end

  % procdata.line affects the operation of proc_ffids
  % so, set them now and restore on exit

  pl = procdata.line;
  pv = procdata.vintage;

  procdata.line = lineno;
  procdata.vintage = -1;	% allow all data from this line

  src111 = [];
  rec111 = [];
  trc111 = [];

  if nargin >= 1 
	if isempty(lineno) || lineno(1) == 0;
		line111 = [];
	else
		line111 = lineno(1);
	end
  else
	line111 = [];
  end

  if nargin >= 2
	if isempty(pattno)
		patt111 = 0;
	else
		patt111 = pattno(1);
	end
  else
	patt111 = 0;
  end

  % go through all files and output geometry in src1 and rec1

  proc_ffids(@extract_geometry1)	

  src = src111;
  rec = rec111;
  trc = trc111;

  % restore procdata

  procdata.line = pl;
  procdata.vintage = pv;

end

