%% Loads one shot record by FFID number from directory 'data/'
%% and adds its geometry info iin global matrices rec111 and src111
%% See extract_geometry.m for formats of these matrices:
%%      src111 - source matrix with nine columns:
%%		1) source number;
%%		2) station number;
%%		3) FFID for this source 
%%		4) inline shift from station (skid)
%%		5) crossline shift from station (offset)
%%		6) inline coordinate 
%%		7)-9) three columns of coordinates (north, east, elevation) 
%%		10) - pattern number into which this source was fired
%%      rec111 - receiver matrix with five columns:
%%		1) surface station number;
%%		2) inline coordinate 
%%		3)-5) three columns of coordinates (north, east, elevation) 
%%	trc - matrix of all traces with 14 columns:
%%		1) line number
%%		2) vintage number
%%		3) pattern number
%%		4) ffid;
%%		5) chan;
%%		6) source station number;
%%		7) receiver station number;
%%		8-10) source coordinates;
%%		11-13) receiver coordinates;
%%		14) flag equal one when the record is good or 0 if it is killed
%% ---------------------------------------------------------------------
%% Parameters:
%%	ffid - ffid number to plot and edit
%%
%%  Returns:
%%      none, all outputs are placed in global matrices src111 and rec111
%% ===============================================================================

function extract_geometry1(ffid)

global src111 rec111 trc111 line111 patt111

  %% load record

  rec = record_ffid(ffid,'data');

  if ~isempty(rec)

%srstn = size(rec.rec_stn)
%srx = size(rec.rec_x)
%srxyz = size(rec.rec_xyz)
%stn = [ min(rec.rec_stn), max(rec.rec_stn), rec.src_stn ]

	if (isempty(line111) || rec.line(1) == line111) && (patt111==0 || rec.pattern(1) == patt111)
  		src111 = [ src111
			rec.source, rec.src_stn, rec.ffid, rec.src_skid, rec.src_offset, rec.src_x, rec.src_xyz ];

		rstn = reshape(rec.rec_stn,[],1);
		one = ones(size(rstn,1),1);

  		rec111 = [ rec111; rstn, reshape(rec.rec_x,[],1), rec.rec_xyz ];

		good = one;
		
  		good(find(ismember(rec.chan,rec.kill)),1) = 0;	% mark killed records with zeros

  		trc111 = [ trc111
			 rec.line(1)*one, rec.vintage*one, rec.pattern*one, rec.ffid*one, ...
			 reshape(rec.chan,[],1), ...
			 rec.src_stn*one, rstn, rec.src_xyz.*one, rec.rec_xyz, ...
			 good ];

		% keep only unique receiver station numbers and pairs of XY source coordinates

		[~,ind] = unique(rec111(:,1));

  		rec111 = rec111(ind,:);

		ind = [];

		for i=1:size(src111,1)
			if ismember(src111(i,7),src111(ind,7)) && ismember(src111(i,8),src111(ind,8))
				continue
			end

			ind = [ ind; i];	% add i to the list of unique (X,Y) coordinates
		end

  		src111 = src111(ind,:);
	end
  end

end

