%%  Retrieves parameters of all available ffids for a given line
%%
%% Parameters:
%%	lineno - line number to retrieve. If empty or not given, retrieves all line numbers
%%	dataset - string parameter. If dataset='raw', raw field records
%%		from directory 'mat/' are used. If dataset='edited', [], or any other,
%%		edited data from directory 'data/' are used.
%%		If this parameter is not given, 'edited' is assumed
%% Returns:
%%	par - matrix with each row containing:
%%		par(:,1) = ffid number
%%		par(:,2) = line number from data file
%%		par(:,3) = source number from data file
%%		par(:,4) = source station from data file (may be edited in 'data/')
%%		par(:,5) = source X (inline coordinate) from data file
%%		par(:,6) = source offset (crossline coordinate) from data file
%%		par(:,7:9) = source coordinates

function par = ffid_params(lineno,dataset)

  if nargin < 1
	lineno = 0;
  end

  if nargin < 2
	dataset='edited';
  end

  %% list all ffids 

  if isempty(dataset)
  	ffid = list_ffids('data/');
  elseif strcmpi(dataset,'raw')
  	ffid = list_ffids('mat/');
  else
  	ffid = list_ffids('data/');
  end

  par = [];

  if strcmpi(dataset,'edited')			% edited data

	for i = 1:length(ffid)

  		matfile = filename_ffid(ffid(i),dataset);

 		if exist(matfile)

			if strcmpi(dataset,'raw')
				load(matfile,"rec")
			else
				% check whether we are in Octave or Matlab

				if inOctave()
					load(matfile,'-mat',"rec")
				else
					load(matfile,"rec")
				end
			end

  			if isempty(rec)
				continue
  			end

			if lineno > 0 && lineno != rec.line(1)		% wrong line
				continue
			end

			par = [ par
				rec.ffid, rec.line(1), rec.source, rec.src_stn, rec.src_x, rec.src_offset, rec.src_xyz ];
		end	%if
	end	% for

  else			% raw

	for i = 1:length(ffid)

  		matfile = filename_ffid(ffid(i),dataset);

 		if exist(matfile)

			if strcmpi(dataset,'raw')
				load(matfile,"rec")
			else
				% check whether we are in Octave or Matlab

				if inOctave()
					load(matfile,'-mat',"rec")
				else
					load(matfile,"rec")
				end
			end

  			if isempty(rec)
				continue
  			end

			if lineno > 0 && lineno != rec.line(1)		% wrong line
				continue
			end

			par = [ par
				rec.ffid, 0, rec.source, rec.src_stn, zeros(1,5) ];	% coordinates unknown
		end	%if

	end

  end	% if data

end

