%%  Returns data and log file names used by various programs
%%  The paths in file names are relative to the current (code) directory 

%% Parameters:
%%      ffid - FFID number 
%%	dataset - optional string parameter. If dataset='raw', raw field 
%%		directory 'mat/' is used. If dataset='edited' or any other,
%%		edited data directory 'data/' is used.
%%		If this parameter is not given, 'edited' is assumed.

%% Returns:
%%      logf - name of log file
%%      dataf - name of .mat data file 
%%	filetype - for 'raw' data, the output file type string equals:
%%		"seism" for our seismograph files 
%%			(ascii Octave workspace in directory 'mat/')
%%		"accel" - accelerometer files by Chelsey 
%%			(text data tables in directory 'accel/')
%%		For pre-processed (edited) data, filetype = 'proc'

function [ logf, dataf, filetype ] = file_names( ffid, dataset )

global procdata

  % obtain log file name for required line number

  if isempty(procdata.line)				% try all logs
  	logf = filename_log('./',0,ffid);
  else
  	logf = filename_log('./',procdata.line(1),ffid);	% if procdata.line(1)==0, will try all logs
  end

  %if isempty(logf)
%	error("No log file for line %d",procdata.line(1));
  %end

  if isempty(logf)		% this must be an invalid ffid
	dataf = '';
	filetype = '';
  else
  	[ dataf, filetype ] = filename_ffid( ffid, dataset );
  end

end

