%% Returns the name of a FFID .mat file in directory mat/, accel/, or  data/
%% 
%% Parameters:
%%      ffid - requested FFID number 
%%	dataset - optional string parameter. 
%%			If dataset='raw', raw field or accelerometer data are used.
%%			If directory 'accel/' exists, the output filetype is set equal 'accel'
%%			and the files in it are expected to be accelerometer data.
%%			If 'accel/' does not exist, directory 'mat/' is used,
%%			and the data are RGIM seismograph data (filetype='seism');
%%		If dataset='edited' or any other,
%%		edited data directory 'data/' is used.
%%
%%		If this parameter is not given, 'edited' is assumed.
%%
%% Returns:
%%	fn - file name for FFID 'ffid'
%%	filetype - for 'raw' data, the output file type string equals:
%%		"seism" for our seismograph files 
%%			(ascii Octave workspace in directory 'mat/')
%%		"accel" - accelerometer files by Chelsey 
%%			(text data tables in directory 'accel/')
%%		For pre-processed (edited) data, filetype = 'proc'
%% =========================================================================================

function [ fn, filetype ] = filename_ffid( ffid, dataset )

  if nargin >= 2
	if strcmpi(dataset,'raw')

  		if isdir("accel")	% accelerometer data directory exists; 
					% this must be Chelsey's 'Trial' accelerometer data

  			fn = sprintf('accel/Trial_%03d_output.txt',ffid);
			filetype = "accel";
  		else
  			fn = sprintf('mat/f%05d.mat',ffid);
			filetype = "seism";
		end

		return
	end
  end

  fn = sprintf('data/f%05d.mat',ffid);	% edited data by default
  filetype = "proc";

end

