%% Returns the name of a .mat file with interpretation of a given ffid
%% 
%% Parameters:
%%      num - requested FFID or CMP number 
%%	dataset - optional string parameter. 
%%			If dataset='ffid' (default), the name of .mat file related to a selected
%%			ffid is returned
%%			If dataset='cmp', the name of .mat file related to cmp number = num is returned
%%
%%		If this parameter is not given, dataset='ffid' is assumed.
%%
%% Returns:
%%	fn - name for pick file for FFID or CMP 'num'
%%	fn_avpick - name for average pick file for ID 'num'
%% =========================================================================================

function [ fn, fn_avpick ] = filename_interp( num, dataset, vintage )

global procdata

  if nargin < 2
	dataset = 'ffid';
  end

  if nargin < 3
	vintage = procdata.vintage;
  end

  fn_avpick = sprintf('interp/interp_l%03d_v%05d_id%05d.mat',procdata.line(1),vintage,num);

  switch dataset
	case 'ffid'

		% check the old file names. They contain redundant line and vintage numbers

  		fn1 = sprintf('interp/interp_f%05d_l%03d_v%04d.mat',num,procdata.line(1),vintage);

		fn = sprintf('interp/interp_f%05d.mat',num);	% new style name

		if exist(fn1)			% rename the old-style file
			movefile(fn1,fn);
		end

	case 'id'		% return average pick file

		fn = fn_avpick;

	case 'cmp'

  		fn = sprintf('interp/interp_cmp%05d_l%03d_v%04d.mat',num,procdata.line(1),vintage);

		fn_avpick = fn;		% for CMP, the picks are always averaged
  end

end

