%% Inserts point 'xy' into matrix 'xy_matr' and updates the index matrix xy_ind 
%% The start and end of the record is recorded in row number 'segment' in output
%% matrix xy_ind_out.
%% If 'segment' < 1, returns unchanged matrices
%% ===============================================================================
%%
%% Parameters:
%%	xy_matr_out, xy_ind_out - data and index matrices to update
%%	segment - number of segment (row in xy_ind) to which point xy is appended
%%	xy - array (can be 1, 2, or any number of values) added in matrix 'xy_matr_out'
%%	sortX - true or false: flag indicating whether to sort input values by X
%%
%% Returns:
%%	xy_matr_out, xy_ind_out - updated xy_matr and xy_ind

function [ xy_matr_out, xy_ind_out ] = insert_point( xy_matr, xy_ind, segment, xy, sortX )

	if nargin < 5
		sortX = true;
	end

	xy_ind_out = xy_ind;

	if segment < 1			% do not insert anything
		xy_matr_out = xy_matr;
		return
	end

	% add a record for this segment if it is not available

	if size(xy_ind_out,1) == 0
		xy_ind_out = zeros(segment,2);
	elseif size(xy_ind_out,1) < segment
		xy_ind_out(segment,:) = [0, 0];
	end

	% find position for insertion and update xy_ind_out

	if xy_ind_out(segment,1) == 0		% new segment

		n = size(xy_matr,1) + 1;
		xy_ind_out(segment,1) = n;

	else
		n = xy_ind_out(segment,2) + 1;
		
		for j=1:size(xy_ind_out,1)

			if j ~= segment && xy_ind_out(j,1) >= n		
				xy_ind_out(j,:) = xy_ind_out(j,:) + 1;
			end
		end
	end

	xy_ind_out(segment,2) = n;

	% insert xy into data matrix

	if n == 1
		xy_matr_out = xy;
	else
		xy_matr_out = [ xy_matr(1:(n-1),:); xy; xy_matr(n:end,:) ];	
	end

	% sort the modified segment

	if sortX
		ind = xy_ind_out(segment,1):xy_ind_out(segment,2);

		[~,ind1] = sort(xy_matr_out(ind,1));

		xy_matr_out(ind,:) = xy_matr_out(ind(ind1),:);
	end
end

