%% Interpolates the exact peaks from dispersion semblance whichj are close to the
%% manual picks obtained interactively 
%% Starting from manual picks in matrix 'modes_xy', nearest to them peak semblance values 
%%	are selected from matrices 'peak' and 'peak1'. These values and the indices of their frequencies
%%	in array 'freq' are output
%% Parameters:
%%      modes_xy - rows from matrix pick.modes_xy containing the picked curve segment of 
%%	freq - array (column) of frequencies for which the output is made
%%	peak - first matrix of semblance peaks, as in 'semb_peak' dispersion semblance structure
%%	peak1 - second matrix of semblance peaks, as in 'semb_peak1' dispersion semblance structure
%% Return:
%%	slwns - column of interpolated nearest slownesses
%%	ind - column of indices of frequency values (in 'freq') 
%%		to which these slownesses 'slwns' correspond
%%	semb - (optional) column of corresponding peak semblance values 

function [ slwns, ind, semb ] = interp_peaks( modes_xy, freq, peak, peak1 )

global procdata

  	minf = min(modes_xy(:,1));
  	maxf = max(modes_xy(:,1));

	ind = find( freq >= minf & freq <= maxf );

	if nargout > 2
		semb = interp1(peak(:,1),peak(:,3),freq(ind));
	end

	slwns0 = interp1(modes_xy(:,1),modes_xy(:,2),freq(ind));	% picked values

	slwns = slwns0;		% do not use interpolation of semblance peaks for now
	return

	% interpolation of exact positions of semblance peaks

	slwns = interp1(peak(:,1),peak(:,2),freq(ind));			% exact values
	slwns1 = interp1(peak1(:,1),peak1(:,2),freq(ind));

	% if 'pick1' is closer to the interactive ones than 'pick', use 'pick1'

	k = find( abs(slwns1-slwns0) < abs(slwns-slwns0) );

	if ~isempty(ind)
		slwns(k,:) = slwns1(k,:);
	end

%peak
%peak1
%slwns

end

