%% Returns coordinates of a point measured by station number and offset from the line
%% ---------------------------------------------------------------------
%% Parameters:
%%	sxyz - matrix with four columns:
%%		station numbers,
%%		x,y,z coordinates of these stations
%%      stno - station number (can be a column and non-integer)
%%		values of stno should match the first column in sxyz
%%		If parameters stno and offset are not given, 
%%	skid - (column) in-line shifts forward relative to the stations
%%		If not given, skid = 0 is assumed
%%	offset - (column) cross-line offsets to the right
%%		If not given, offset = 0 is assumed

%%
%%  Returns:
%%	in_line - column of in-line coordinates for 'stno'
%%      xyz - matrix with four columns:
%%		column of station numbers
%%		three columns of coordinates (north, east, elevation) 
%% =====================================================================

function [ in_line, xyz ] = line_coords( sxyz, stno, skid, offset )

  if nargin < 3
	skid = zeros(length(stno),1);
  else
  	skid = reshape(skid,[],1);
  end
 
  if nargin < 4
	offset = zeros(length(stno),1);
  else
  	offset = reshape(offset,[],1);
  end

  stno = reshape(stno,[],1);

  % measure distance from the end

  nxy = min([ size(sxyz,2), 4]);	% number of last column in sxyz to use

  n = size(sxyz,1);
  x = zeros(n,1);
  xmp = zeros(n,1);
  az = zeros(n,1);

  for i=2:n
	i1 = i-1;

	[ d, az(i,1) ] = distance(sxyz(i1,2:nxy),sxyz(i,2:nxy));

	x(i) = x(i1) + d;
	xmp(i) = x(i1) + d*0.5;		% distances to midpoints at which 'az' is evaluated
  end

  az(1,1) = az(2,1);

%sxyz
%az
%stno
%skid
%x

  in_line = reshape(interp1(sxyz(:,1),x,stno,'linear','extrap') + skid,1,[]);

  if nargout >= 2

  	xyz = interp1(x,sxyz(:,2:nxy),in_line,'linear','extrap');

	if nargin >= 3		% apply skid and offset
  		a = transpose(interp1(xmp,az,in_line,'linear','extrap') + 0.5*pi);	% direction of offset

%d = [sxyz(:,1:nxy), xmp, az ]

		xyz(:,1:2) = xyz(:,1:2) + offset .* [ cos(a), sin(a) ];
	end
  end

end

