%% In 'lst', returns column containing a sorted list of all ffids 
%% present in directory 'mat/' of current project. The files
%% are recognized by extension '.mat'
%% If parameter procdata.line is not empty, returns only ffids listed in
%% log file for line number procdata.line(1). If procdata.line is empty, returns
%% all ffids in 'directory'
%% ==============================================================================
%% Parameters:
%%	directory - name of directory in which to look for files
%%
%% Returns:
%%	lst - column of sorted ffids in the directory
%% 	last - the largest FFID value or 0 if the list is empty
%%
%% Usage examples:
%%	ffid_list = list_ffids("mat/")

function [ lst, last ] = list_ffids(directory)

global procdata

  % drop the trailing '/' from directory name

  if directory(end) == '/'
  	directory(end) = [];	
  end

  lst = [];

  switch directory

    case 'accel'

  	lf = list_files( directory, ".txt" );

	% extract ffid (trial) numbers
	% parse out the first integer in each file name

	for i=1:size(lf,1)
		s = lf(i,:);
		s(find(s=='_')) = ' ';	% replace '_' in file names by spaces

		[ tok s ] = strtok(s);

		while ~isempty(tok)

			n = str2num(tok);

			if isfinite(n)
				lst(i,1) = n;
				break
			end

			[ tok s ] = strtok(s);
		end
	end

    otherwise

  	lf = list_files( directory, ".mat" );

  	if ~isempty(lf)
		lst = sort(str2num(lf(:,2:end)));
  	end

  end

  % reduce lst to ffid numbers matching procdata.line(1) and procdata.vintage

%directory
%lf
%lst
%pl = procdata.line
%pv = procdata.vintage

  if ~isempty(procdata.line) 

  	logf = filename_log('./',procdata.line(1));

	if ~isempty(logf)
		[ ~, ffid1, ~, ~, ~, ~, ~ ] = params_line(logf,procdata.line(1),procdata.vintage);

		ind = find(ismember(lst,ffid1));

		lst = lst(ind,:);
	end
  end

  if isempty(lst)
	last = 0;
  else
	last = lst(end);
  end

end

