%% Interactive update of phase-semblance picks in 'dispsemb' structure
%% =====================================================================
%%
%%	The picking is conducted in current figure
%%
%% Parameters:
%%	xy_matr_out, xy_ind_out - data and index matrices to update
%%				by interactive picking

%%	param - structure containing parameters of the picking session

function [ xy_matr, xy_ind, status ] = pick_segments(xy_matr_in, xy_ind_in, param)

global procdata

  xy_matr = xy_matr_in;
  xy_ind = xy_ind_in;

  % query the limits of the current plot and make scalars to scale its dimensions to (1,1)

  dx = xlim();
  dy = ylim();

  scales = [ 1.0/(dx(2)-dx(1)), 1.0/(dy(2)-dy(1)) ];

  lh = zeros(size(xy_ind,1),2);		% list of line handles

  pick_mode = 0;	% no picking on startup

  while 1

	% draw lines and markers

	lh = plot_segments( lh, xy_matr, xy_ind, param.marker);		% use default solid line

	% display legend  for active handles

	ind1 = find(lh(:,1));	% numbers of actually displayed handles 

	if ~isempty(ind1)
		legend(lh(ind1,2),param.segment_list(ind1))
	end

  	if pick_mode
		title(sprintf("Picking '%s' in %s\n%s",param.name(pick_mode,:), param.title, param.help_line))
	else
		title(sprintf("%s\n%s",param.title, param.help_line))
	end

	[x,y, buttonNumber] = ginput(1);
  
	switch buttonNumber

	  case 1		% left button - insert point if pick_mode >= 0

%xy_matr
%xy_ind

		% if X is close to an existing point, change it, otherwise insert new

		if pick_mode && xy_ind(pick_mode,1)>0		% will be looking within the branch
								% currently being picked
			ind1 = xy_ind(pick_mode,1):xy_ind(pick_mode,2);
 		else
			if size(xy_matr,1)
				ind1 = 1:size(size(xy_matr,1));		% look across all points
			else
				ind1 = [];
			end
		end

%ind1
		if length(ind1) > 0
			[ d, ind ] = min(abs((xy_matr(ind1,1) - x).*scales(1))); % nearest by X previous pick
		else
			ind = [];
		end

		if isempty(ind) || d > param.vicinity		% clicked on new point
			[ xy_matr, xy_ind ] = insert_point(xy_matr,xy_ind,pick_mode,[x,y]);

		else						% change 'ind'
			ind = ind1(ind);					
			xy_matr(ind,:) = [ x, y ];

			pick_mode = find_segment(xy_ind, ind);	% also switch to picking this segment
		end

	  case 3		% right button - delete near pick

		[ d, ind ] = min(sum(((xy_matr - [x,y]).*scales).^2,2));	% nearest previous pick

		if sqrt(d) < param.vicinity
			[ xy_matr, xy_ind ] = delete_point(xy_matr,xy_ind,ind);

			pick_mode = find_segment(xy_ind, ind);	% also switch to picking this segment
		end

	  case '+'		% increase mode numbers (shift rows of xy_ind upward)

		[ xy_matr, xy_ind ] = delete_segment(xy_matr,xy_ind,size(xy_ind,1));

		xy_ind(1:(end-1),:) = xy_ind(2:end,:);

	  case '-'		% decrease mode numbers (shift rows of xy_ind downward)

		[ xy_matr, xy_ind ] = delete_segment(xy_matr,xy_ind,1);

		xy_ind(2:end,:) = xy_ind(1:(end-1),:);

	  case 'm'		% select mode and start/stop picking 

		n = listdlg('PromptString',param.menu_header,...
					'SelectionMode','single','InitialValue',pick_mode+1,...
					'ListString',param.menu_list);

		if ~isempty(n)
			pick_mode = n-1;
		end

	  case 'd'		% delete one or several segments, or or all data

		n = listdlg('PromptString','Delete segments',...
					'SelectionMode','multiple','InitialValue',pick_mode+1,...
					'ListString',param.segment_list);

		[ xy_matr, xy_ind ] = delete_segment(xy_matr,xy_ind,n);

	  case {'x', 'n'}

	       query = questdlg(param.query_next, param.query_banner, 'YES', 'NO', 'NO');
	       drawnow

	       switch lower(query)
		    case 'yes'

			status = 'next';
			break

		    case 'no'
			 
	       end 		% switch query

	  case 'q'

	       query = questdlg(param.query_stop, param.query_banner, 'YES', 'NO', 'NO');
	       drawnow

	       switch lower(query)
		    case 'yes'

			status = 'stop';	% ask proc_ffids() to stop
			break

		    case 'no'
			 
	       end 		% switch query

	  otherwise		% other keys

	end		% switch buttonNumber

  end		% big endless while loop

end

