%% Set plot axes according to current plotting mode
%%
%% Parameters:
%%	plot_title - optional plot title
%%	plot_mode - optional mode like 'procdata.plot_modes'
%%		If not specified, procdata.plot_modes is used
%%	x_limits, y_limits - optional limits for the axes. If not specified or equal [].
%%		limits from procdata.plot_freq_range, etc., are used. If the limits 
%%		in procdata are empty, commands xlim() or ylim() are not issued

function plot_axes( plot_title, plot_mode, x_limits, y_limits )

global procdata

	if nargin < 2
		plot_mode = procdata.plot_modes;
	end

	if nargin < 3
		x_limits = [];
	end

	if nargin < 4
		y_limits = [];
	end

	switch  lower(plot_mode)

		case 'fv'

			if ~isempty(x_limits)
				xlim(x_limits);

			elseif ~isempty(procdata.plot_freq_range)
				xlim(procdata.plot_freq_range);
			end

			if ~isempty(y_limits)
				ylim(y_limits);

			elseif ~isempty(procdata.plot_V_range)
				ylim(procdata.plot_V_range);
			end

 			xlabel('Frequency (kHz)')
  			ylabel('Phase velocity (m/ms)')

		case 'fs'

			if ~isempty(x_limits)
				xlim(x_limits);

			elseif ~isempty(procdata.plot_freq_range)
				xlim(procdata.plot_freq_range);
			end

			if ~isempty(y_limits)
				ylim(y_limits);

			elseif ~isempty(procdata.plot_slwns_range)
				ylim(procdata.plot_slwns_range);
			end

  			xlabel('Frequency (kHz)')
  			ylabel('Phase slowness (ms/m)')

		case 'ks'

			if ~isempty(x_limits)
				xlim(x_limits);

			elseif ~isempty(procdata.plot_kx_range)
				xlim(procdata.plot_kx_range);
			end

			if ~isempty(y_limits)
				ylim(y_limits);

			elseif ~isempty(procdata.plot_slwns_range)
				ylim(procdata.plot_slwns_range);
			end

  			xlabel('kx (1/m)')
  			ylabel('Slowness (ms/m)')

		case 'zvs'

			% restrict velocity or depth range
				
			if ~isempty(x_limits)
				xlim(x_limits);
	    
			elseif ~isempty(procdata.plot_V_range)
				xlim(procdata.plot_V_range);
			end
			
			if ~isempty(y_limits)
				ylim(y_limits);
	    
			elseif ~isempty(procdata.plot_Z_range)
				ylim(procdata.plot_Z_range);
			end

			set(gca,'Ydir','reverse')

  			xlabel('Vs (m/ms)')
  			ylabel('Pseudodepth (m)')
	end

	grid on

	if nargin >= 1
		title(plot_title)
	end
end

