%% Creates a plot of dispersion semblance cross-section in current figure
%% The 3-D semblance violum is sliced at the given velocity value, and
%% the image is presented as a pseudosection: (wavelength, cmp X coordinate)
%%
%% Parameters:
%%	dsemb - structure containing dispersion semblance and picks
%%	vel - phase velocity at which the section is extracted from 3-D cube of semblance

function plot_dispersion_v(dsemb,vel)

global procdata

  Nlambda = 100;		% number of points in vertical grid 

  s = 1/vel;		% desired slowness

  if s > dsemb.slwns(end) || s < dsemb.slwns(1)		% out of range
	return
  end
  
  % range of lambda

  lr = [ vel/procdata.plot_disp_freq_range(2),vel/procdata.plot_disp_freq_range(1) ];

  if ~isempty(procdata.plot_disp_lambda_range)
	lr(1) = max([lr(1),procdata.plot_disp_lambda_range(1)]);
	lr(2) = min([lr(2),procdata.plot_disp_lambda_range(2)]);
  end

  lambda = linspace(lr(1),lr(2),Nlambda);

  semb1 = zeros(length(dsemb.f),length(procdata.cmp_loc));
  semb = zeros(length(lambda),length(procdata.cmp_loc));

  % first, interpolate by slowness

  for i=1:size(semb1,1)
    for j=1:size(semb1,2)
	semb1(i,j) = interp1(dsemb.slwns,dsemb.semblance(i,:,j),s,'linear');
    end
  end

  % next, interpolate frequencies

  semb = interp1(dsemb.f,semb1,vel*lambda.^(-1),'linear');

  % normalize the peak value in each vertical column

  semb = semb ./ (max(semb) + 1.0e-16);

  pseudodepth = lambda*0.5;		% pseudodepth for plotting = half wavelength

  imagesc(procdata.cmp_loc,pseudodepth,semb)

  colorbar

  if isempty(procdata.plot_Z_range)
  	ylim([0,max(pseudodepth)])
  else
  	ylim(procdata.plot_Z_range)
  end

  xlabel('Distance, m')
  ylabel('Wavelength, m')
  
  grid on

end

