%% Creates subplots for checking geometry in the edited records in 'data/'
%% Plotting lines in rows and vintages in columns

%% ================================================================================

function plot_geometry()

global procdata

  % extract records from all available ffids

  [ ~, ~, trc ] = extract_geometry();	

%%		Mapping of trc columns (from extract_geometry.m):
%%		1) line number
%%		2) vintage number
%%		3) pattern number
%%		4) ffid;
%%		5) chan;
%%		6) source station number;
%%		7) receiver station number;
%%		8-10) source coordinates;
%%		11-13) receiver coordinates;
%%		14) flag equal one when the record is good or 0 if it is killed

  % extract lists of lines and vintages

  vints = unique(trc(:,2));
  lines = unique(trc(:,1));

  nl = length(lines);
  nv = length(vints);

  % find smallest and largest coordinates 

  xy0 = min([ trc(:,11:12); trc(:,8:9) ]);
  xy1 = max([ trc(:,11:12); trc(:,8:9) ]);

  % plot range 

  dxy = xy1 - xy0;

  northlabel = sprintf("Inline (m)");
  eastlabel = sprintf("Crossline (m)");

  % make a separate plot for each vintage

  for i = 1:nl
      for j = 1:nv

	% extract this line and vintage from trc

	trc1 = trc(find( trc(:,1)==lines(i) & trc(:,2)==vints(j)),:);
	
	if isempty(trc1)
		continue
	end

	subplot(nl, nv, j+(i-1)*nv)		% set plotting box
	hold on

	% plot receiver coordinates
	% (do not do this now!) shift coordinate origins to 0,0, so that the values are smaller

	c1 = unique2(trc1(:,11:12));	% XY coordinates

	plot(c1(:,2),c1(:,1),'b+')

	% plot source coordinates

	s1 = unique2(trc1(:,8:9));	% XY coordinates

	plot(s1(:,2),s1(:,1),'rx')

	% print ffids near each source

	for k=1:size(s1,1)

		trc2 = trc1(find( sum((trc1(:,8:9) - s1(k,:)).^2,2) < 1.0e-8),:);	% records for this source
		ffid = unique(trc2(:,4));

		if isempty(ffid)
			continue
		end

		ffidlabel = sprintf("f %d",ffid(1));

		for l=2:length(ffid)
			ffidlabel = sprintf("%s,%d",ffidlabel,ffid(l));
		end

		text(s1(k,2)+0.05,s1(k,1),ffidlabel)
	end

	if ~isempty(procdata.plot_XY_range)
		axis(procdata.plot_XY_range)
	end

	grid on

	%axis("equal")
	title(sprintf("Line %d, Vintage %d",lines(i), vints(j)))
	ylabel(northlabel)
	xlabel(eastlabel)

    end 	% for j

  end	% for i

% output the figure in jpeg

warning("off"); 		% suppress annoying warnings from print()

dirname = sprintf('plots/geometry/');

mkdir(dirname);
print(sprintf('%s/maps',dirname),'-djpeg');

warning("on"); 



