%% Helper for plot_modes() executing all actions for one file with specified vintage
%%
%% Parameters:
%%      num - requested FFID or CMP number 
%%	vintage - optional vintage number overriding procdata.vintage

function plot_modes1(num, vintage)

global procdata modes
persistent need_model

  need_model = true;

  fn = filename_interp( num, procdata.dataset, vintage );

%num
%vintage
%fn
%color = procdata.marker_color
%vintlist = procdata.vint_list
%pdd = procdata.dataset
%pm = procdata.plot_modes

  if exist(fn)
	load(fn)
  else		% pick file does not exist, just use the autopicks

	
	[ pick, param ] = autopick_dispersion(num);
  end

%ps = procdata.subplot
%pd = procdata.id
%pid = [ pick.id, pick.number ]

  % if subplot required, only use data with id corresponding to it

  if ~isempty(procdata.subplot)
	if pick.id < procdata.subplot(1) || pick.id > procdata.subplot(2)	% out of range
		return
	end

	subplot(procdata.subplot(3),procdata.subplot(4),procdata.subplot(5:6))
	hold on
	grid on
	    
	plot_axes();

	switch  lower(procdata.plot_modes)

		case 'zvs'

			% plot model

			if need_model

				for jk = procdata.subplot(1):procdata.subplot(2)
%jk
%modes
					if ~isempty(modes)

					  if modes.id ~= jk	% wrong plot for these model and modes
						continue
					  end

					  plot_model_modes1();	% plot curves (f,V), pseudodepth, etc.

					  % plot the layered S-wave model

					  plot_model1('s');

					  need_model = false;	% do not need to redraw model

					end	% if

				  end	% for jk
			end	% if need_model

		end	% switch

  end	% if ~empty subplot

  if ~isempty(procdata.id)		% use only records with ids in this list

	switch lower(procdata.location_id)

		case { 'number', 'ffid', 'cmp' }

			if ~ismember( pick.number, procdata.id)
				return
			end

		otherwise		% 'id' is default
			if ~ismember( pick.id,procdata.id)
				return
			end
	end
  end

  marker = param.marker;

  % modify color of markers based on procdata.marker_color or vintage numbers

  if ~isempty(procdata.vint_list)		% use vintages

	if procdata.vint_list(1) < 0	% -1 is given as requested vintage

		[ ~, vintages ] = list_line(procdata.line(1));	% obtain all vintages for this line
	else
		vintages = procdata.vint_list;
	end

	j = find(vintages == pick.vintage);

	if ~isempty(j)		% this vintage is in color list

		for i=1:size(marker,1)
			marker(i,2) = procdata.marker_color(rem(j-1,length(vintages))+1);
		end
	end

	plot_legend = ismember(pick.vintage,vintages);

  else		% use procdata.marker_color

	for i=1:size(marker,1)
		marker(i,2) = procdata.marker_color(rem(i-1,length(procdata.marker_color))+1);
	end

	vintages = [];
	plot_legend = true;
  end

%pdv = procdata.vint_list
%vintages
%marker

%pxy = pick.modes_xy
%pm = pick.modes

  lh1 = zeros(size(pick.modes,1),2);		% list of line handles

  lh1 = plot_segments(lh1, pick.modes_xy, pick.modes, marker);

	% place label by the right end of the segment

  if procdata.plot_modes_ids
	[ x, ind ] = max(pick.modes_xy(:,1));

	x = x + (x - min(pick.modes_xy(:,1)))*0.03;	% slight shift to the right

	xy = plot_coords( [x, pick.modes_xy(ind,2) ]);
%xy
%pn = pick.number

	text(xy(1), xy(2), num2str(pick.number));
  end

  ind = find(lh1(:,1));	% numbers of displayed segments

  % if procdata.plot_group is not specified, use vintage to form legend

  if plot_legend
	if isempty(procdata.plot_group)	
		procdata.lh = [ procdata.lh; ind,  ones(size(ind,1),1)*pick.vintage, lh1(ind,2) ];	
				% segment numbers, group numbers, and handles 
	else
		procdata.lh = [ procdata.lh; ind,  ones(size(ind,1),1)*procdata.plot_group, lh1(ind,2) ];	
				% segment numbers, group numbers, and handles 
	end
  end

%lh1
%plh0 = procdata.lh

%pl = procdata.line
%pr = procdata.run
%plhmodes = procdata.lh

end

