%% Plot picked wave modes in different colors by FFID groups

%% Parameters:
%% 	Function takes an arbitrary number of parameters which should be used in pairs:
%%		ffid_range1, color1, ffid_range2, color2, ...
%% 	The ffid_range should be an array of FFIDs to plot in the corresponding 'color', 
%%		e.g. min_FFID:max_FFID
%% 	'color' can be any color symbol accepted in plot(): 'k','r','g','b','c','m'. etc.
%% 	If color argument is missing at the end of parameter list, 'k' will be used.
%%
%% Plotting is performed by using proc_ffids()

function plot_modes_ffid( varargin )

global procdata

  run('../config/settings.m')		% obtain settings in structure 'sett'

  procdata.dataset = 'ffid';		% force the FFID-sorted dataset

  figure(81)				% open one wide figure
  clf
  set(gcf,'Position',sett.window_wide)	

  mode_name = [ 'N  '; 'N-1'; 'N-2'; 'N-3' ];	% mode names for legend

  procdata.vint_list = [];
  procdata.vintage = [];		% no selection by vintage

  procdata.lh = [];	% create persistent array of line handles

  nchars = 20;		% number of characters in group names

  group_name = blanks(nchars);

  % go through pairs of arguments

  narg = 1;
  procdata.plot_group = 0;		% FFID group number to put in the legend

  minffid = [];
  maxffid = [];

  while narg <= nargin
	
	select = varargin{narg};	% list of ffids to select

	narg = narg + 1;
	procdata.plot_group = procdata.plot_group + 1;

	if narg <= nargin 
		procdata.marker_color = varargin{narg};
	else
		procdata.marker_color = 'k';
	end

	narg = narg + 1;

	% form FFID group names for legend

	if length(select) < 1		% nothing to do
		continue
	elseif length(select) < 2
		str = [ ' ffid ', num2str(select(1)) ];
	else
		str = [ ' ffid ', num2str(min(select)),' - ',num2str(max(select)) ];
	end

	if length(str) < nchars
		str = [ str, blanks(nchars - length(str)) ];
	end

	% put the min and max number into the total range of ffids

	minffid = min([minffid, min(select)]);
	maxffid = max([maxffid, max(select)]);

	group_name(procdata.plot_group,:) = str(1:nchars);

	if isempty(procdata.subplots)		% make one pass through FFIDs or CMPs
		procdata.subplot = [];
		proc_ffids(@plot_modes,[],'data',select);

  		plot_axes(sprintf('Line %d: Dispersion picks from %s',line_no, procdata.dataset))
  		grid on

	else					% repeat passes for each subplot
		for i=1:size(procdata.subplots)
			procdata.subplot = procdata.subplots(i,:);
			proc_ffids(@plot_modes,[],'data', select);

			if procdata.subplot(1) > 0	% valid plot, not legend only

				if procdata.subplot(1) == procdata.subplot(2)				% only one ID
					titl = sprintf('Dispersion picks from %s, ID %d',...
							procdata.dataset, procdata.subplot(1) );
				else									% ID range
					titl = sprintf('Dispersion picks from %s, ID %d-%d',...
							procdata.dataset, procdata.subplot(1), procdata.subplot(2) );
				end

				plot_axes(titl)
 				grid on
			end
		end
	end
  end		% while loop

  procdata.lh = unique2(procdata.lh); 	% leave in 'lh' only one record per segment and FFID group

  % display legend in the last panel 

  if ~isempty(procdata.lh)
	lgd = mode_name(procdata.lh(:,1),:);

	lgd = [ lgd, group_name(procdata.lh(:,2),:) ];

%lgd

	if ~isempty(procdata.subplots)
		subplot(procdata.subplots(end,3),procdata.subplots(end,4),procdata.subplots(end,5))
		hold on

			%axes('Visible','off')
	end

	legend(procdata.lh(:,3),lgd,'location','southeast')
  end

  % output the figure in jpeg

  if ~isempty(minffid)

  	fn = sprintf('modes_f%05d-f%05d_%s',minffid,maxffid,procdata.plot_modes);

  	warning("off"); 		% suppress annoying warnings from print()

  	dirname = 'plots/modes/';

  	mkdir(dirname);

  	figure_jpeg(dirname,fn);

  	warning("on"); 
  end

end	% function

