%% plot_modes_line() for one line and ID only, without subplots, and without jpeg outputs
%%
%% Parameters:
%%      line_no - line number to plot
%%	ID - location id to plot for
%%	vint_list - list of vintages to plot
%%	vint_color - character matrix of color symbols for the vintages in 'vint_list'

function plot_modes_line1(line_no, ID, vint_list, vint_color )

global procdata model modes sett

	if nargin < 3
  		vint_list = -1;		% all vintages
	end

	if nargin < 4
  		vint_color = [ 'k','r','g','b','c','m' ];
	end

	ps = procdata.subplots;		% save current subplots

	procdata.subplots = []; %[ ID, ID, 1, 1, 1:1 ];
	procdata.subplot = [];
	procdata.id = ID;

	pdvl = procdata.vint_list;		% save the vintage list

	mode_name = [ 'N  '; 'N-1'; 'N-2'; 'N-3' ];	% mode names for legend

	% create lists of vintages, marker colors, and labels

	procdata.marker_color = vint_color;
	procdata.vint_list = vint_list;
  	procdata.plot_group = [];		% group not specified; will use vintage to form plot legend

	% create a double loop to process all lines and vintages desired
	% for each line, create a separate figure with plots of all vintages overlaid

	procdata.lh = [];	% create persistent array of line handles

	procdata.line = line_no;

	for vint_no = vint_list

		procdata.vintage = vint_no;

		% make one pass through FFIDs or CMPs
	
		switch lower(procdata.dataset)
		  	case 'id'
				proc_ids(@plot_modes)
			otherwise
				proc_ffids(@plot_modes)
			end

	end	% vint_no

%plh = procdata.lh

  	procdata.lh = unique2(procdata.lh); 	% leave in 'lh' only one record per segment and vintage group

	procdata.vint_list = pdvl;		% restore the vintage list
	procdata.subplots = ps;			% restore the subplots
end

