%% Plots waveforms from rec in current figure
%% ====================================================================
%%
%% Parameters:

function rec = plot_rec(rec, gain, time_range)

global procdata
	
  subplot(4,1,1:3)

  hold on	% this makes the different plot() commands to overlay the curves

  % draw a green circle at channel number corresponding to the position of the source  

  plot(rec.src_stn+rec.src_skid - rec.rec_stn(1) + rec.chan(1),0.0,'go')

  for i=1:length(rec.chan)
	chan = rec.chan(i);

	d = data(:,i);
	t = rec.times;

	% draw the trace 

	if ismember(chan,rec.kill)
 		plot(d/(max(abs(d))+1.e-8)*gain+chan,t,'r-')
	else
 		plot(d/(max(abs(d))+1.0e-8)*gain+chan,t,'b-')
	end
  end

  % draw the tt model in near traces by black lines

  if ~isempty(rec.tt_near)
  	plot(rec.chan(ind_near),polyval(rec.tt_near,abs(rec.offset(ind_near))),'k-')
  end

  % draw crosses at first-arrival picks  

  if ~isempty(rec.picks_fb)
  	plot(rec.chan(rec.picks_fb(:,1)),rec.picks_fb(:,2),'kx')
  end

  xlim([rec.chan(1)-1, rec.chan(end)]+1)
  ylim([rec.times(1), rec.times(end)])

  set(gca,'Ydir','reverse');
  set(gca,'XTick',rec.chan(1):2:rec.chan(end));

  ylabel("Time (ms)")
  xlabel("Channel number and Ground velocity")
  title( sprintf("Line %d; FFID %d; SRC at stn=%d skid=%1.2f m offset=%1.2f m; ts = %1.1f ms", ...
		procdata.line, ffid, rec.src_stn, rec.src_skid*rec.line(4), rec.src_offset, time_start ) )

  subplot(4,1,4)

  plot(rec.chan,rec.offset,'b-')

  grid on
  ylabel("Offset (m)")
  xlabel("Channel number")

end



