%% Draws in current figure segments stored in an indexed matrix
%% Parameters:
%%	lh - matrix with two columns representing the state of line handles
%%		Rows of the matrix correspond to rows of xy_ind (segments)
%%		First column is binary flags 0 or 1, with 1 meaning the line is displayed, 
%%		second column are the handles. 
%%	xy_matr, xy_ind - data and index matrices for the branches
%%	marker - matrix with rows corresponding to rows in xy_ind and containing two-character strings
%%		(marker,color)
%%	linestyle - LineStyle attribute ('-', '--')
%%
%% Returns
%%	lh_out - matrix with the output state of lh

function lh_out = plot_segments( lh, xy_matr, xy_ind, marker, linestyle)

global procdata

	if nargin < 5
		linestyle = '-';
	end

%linestyle
%marker

	lh_out = lh;
	lgnd = [];

	% draw lines and markers

	for i=1:size(xy_ind,1)

		if lh_out(i,1)
			delete(lh_out(i,2));
			lh_out(i,1) = 0;
		end

		if xy_ind(i,1) < 1
			continue
		end

		ind = xy_ind(i,1):xy_ind(i,2);

		lh_out(i,1) = 1;	% flag meaning the line is displayed

		% plot in different coordinates for different plot modes

		xy_plot = plot_coords(xy_matr(ind,1:2));

		lh_out(i,2) = line(xy_plot(:,1),xy_plot(:,2),'LineStyle',linestyle,...
						'Marker',marker(i,1),'Color',marker(i,2),'MarkerSize',10);
	end
end

