%%  Processes all cmp data files one by one using the specified program 
%%
%% Parameters:
%%	proc_fun - function handle or name for processing each CMP. This function
%%		should take a single argument equal the CMP number
%%	close_fun - function handle or name for finalizing processing after proc_fun()
%%		returns. If close_fun=[], this function is not called.
%%		For example, use close_fun = @ginput to pause processing 
%%		until the user presses a key.
%%		The function can also output strings that can be used to control processing.
%%		If close_fun() returns string 'stop' or 'q', processing is terminated.
%%	select - list of CMPs to select. If select==[], all indices in procdata.cmp_loc are tried
%%
%% Usage examples:
%%	proc_cmpss(@pick_dispersion)	% @ginput is redundant for interactive programs!

function proc_cmps(proc_fun, close_fun, select)

global procdata

  if nargin < 2
	close_fun=[];
  end

  if nargin < 3
	select=[];
  end

  %% list all ffids and process them one by one

  cmp = 1:length(procdata.cmp_loc);

  procdata.num_runs = length(cmp);	% total number of runs which can be used
					% in the functions called in the following loop

  procdata.run_status = 'run';		% use this field to pass instructions from called
					% function

  procdata.data_order = 'cmp';		% make sure all programs know thhat we are looking at cmps

  for i=1:procdata.num_runs

%	disp(sprintf('proc_cmps: run %d, cmp %d',i, cmp(i)))

	if ~isempty(select)
		if ~ismember(cmp(i),select)		% skip
			continue
		end
	end

	procdata.run = i;		% run number in the call to proc_ffids
	procdata.run_cmp = cmp(i);	% cmp number in the call to proc_ffids

	proc_fun(cmp(i));

	if ~isempty(close_fun)
		procdata.run_status = close_fun();
	end

	if strcmpi(procdata.run_status,'stop')
		break
	end
  end
end

