%%  Processes all ID-sorted data files one by one using the specified program 
%%
%% Parameters:
%%	proc_fun - function handle or name for processing each id. This function
%%		should take a single argument equal the id number
%%	close_fun - function handle or name for finalizing processing after proc_fun()
%%		returns. If close_fun=[], this function is not called.
%%		For example, use close_fun = @ginput to pause processing 
%%		until the user presses a key.
%%		The function can also output strings that can be used to control processing.
%%		If close_fun() returns string 'stop' or 'q', processing is terminated.
%%	dataset - string parameter. If dataset='raw', raw field records
%%		from directory 'mat/' are used. If dataset='edited', [], or any other,
%%		edited data from directory 'data/' are used.
%%		If this parameter is not given, 'edited' is assumed
%%	select - list of ids to select. If select==[], all ids are tried
%%
%% Usage examples:
%%	proc_ids(@plot_modes)

function proc_ids(proc_fun, close_fun, dataset, select)

global procdata

  % if full stop was requested, return without doing anything

  if strcmpi(procdata.run_status,'stop')
	return
  end

  if nargin < 2
	close_fun=[];
  end

  if nargin < 3
	dataset=[];
  end

  if nargin < 4
	select=[];
  end

  %% list all ids and process them one by one

  id = [ 1; 15 ];		% this is a temporary test

  if length(id) < 1
	disp(sprintf('proc_ids: No IDs for line %d, vintage %d', procdata.line(1),procdata.vintage))
	return
  end

  if isempty(procdata.vintage)
  	disp(sprintf('proc_ids: %d ids for line %d, vintage []', length(id), procdata.line(1)))
  else
  	disp(sprintf('proc_ids: %d ids for line %d, vintage %d', length(id), procdata.line(1),procdata.vintage))
  end

  procdata.num_runs = length(id);	% total number of runs which can be used
					% in the functions called in the following loop

  procdata.run_status = 'run';		% use this field to pass instructions from called
					% function

  for i=1:procdata.num_runs

	if ~isempty(select)

		if ~ismember(id(i),select)		% skip
			continue
		end
	end

 	% disp(sprintf('proc_ids: run %d, id %d',i,id(i)))

	procdata.run = i;		% run number in the call to proc_ids
	procdata.run_id = id(i);	% id number in the call to proc_ids

	proc_fun(id(i));

	if ~isempty(close_fun)
		procdata.run_status = close_fun();
	end

	if strcmpi(procdata.run_status,'stop')
		break
	end
  end

end

