%% Reads in the pattern file.
%% Pattern file name should be pattern_<pattern_number>.txt 
%% (or it can have any other extension), and the file should contain a column of station numbers and 
%% one to three columns of coordinates. 
%% For example (ignore THE FIRST '%' in each line below):

%% Sensor coordinates
%%   Station #    Inline (cm)	  Crossline from  axis (cm)

%	1		0		16
%	2		5		16
%	3		10		16
%	...

%% ================================================================================

%% Parameters:
%%	pattern_number - requested pattern number
%%	src_stn - one or multiple source station numbers
%%	src_skid - column of skid values (inline shifts) for each source station in src_stn
%%	src_offset - column of offset values (crossline shifts to the right)
%%		 for each source station in src_stn
%%	rec_stn - one or multiple receiver station numbers
%%
%% Returns:
%%	src_xyz - matrix with rows containing (X,Y,Z) coordinates for each element of src_stn
%%	rec_xyz - matrix with rows containing (X,Y,Z) coordinates for each element of rec_stn
%%	src_x - row of inline coordinates of sources in src_stn 
%%	rec_x - row of inline coordinates of receivers in rec_stn 

function [ src_xyz, rec_xyz, src_x, rec_x ] = read_pattern( pattern_number, src_stn, src_skid, src_offset, rec_stn )

global procdata

  fn = sprintf("../config/pattern_%03d.txt",pattern_number);

  d = load(fn,"-ascii");

  if size(d,1) < 2 || size(d,2) < 3
	error("Invalid pattern file %s", fn)
  end

  n = size(d,2)-1;	% number of coordinates given in the file

  % use only up to three coordinates

  if n > 3 
	n = 3;
  end

  src_xyz = zeros(length(src_stn),3);
  rec_xyz = zeros(length(rec_stn),3);

%pattern_number
%d

  [ rec_x, rec_xyz(:,1:n) ] = line_coords( d, rec_stn );
  [ src_x, src_xyz(:,1:n) ] = line_coords( d, src_stn, src_skid, src_offset );

end

