%% Reads in structure 'rec' from an accelerometer output file and
%% processing parameters in 'procdata'
%%
%% ================================================================================
%% Parameters:
%%	datafile - name of .txt file output from one group of accelerometers
%% Returns:
%%	rec - structure containing the record (empty if no such record exists)
%% Usage examples:
%%	rec1 = record_accel("Trial_198_output.txt")

function rec = record_accel(datafile)

global procdata

	d = load(datafile,'-ascii');   
 
	rec.times = d(:,1);		% times of sampling

	rec.dt = d(2,1) - d(1,1);	% sampling interval

	rec.aux = d(:,2);		% auxiliary record: source (hammer) data 
	rec.data = d(:,3:end);		% receiver data records

	rec.chan = 1:size(rec.data,2);	% channel numbers assigned to these records

	rec.rec_stn = rec.chan;		% in accelerometer data, receiver stations are
					% simply numbered sequentially, the same as channels

	rec.kill = [];			% no killed records in these data

	rec.offset = rec.chan;		% dummy default offsets
end

