%% Calculates dispersion semblance structure 
%% =====================================================================
%%
%% Parameters:
%%	rec - time-domain record
%%	spec - spectra for the record
%%	procd - structure with processing parameters, 
%%		which is normally a copy of user's 'procdata'
%%
%% Returns:
%%	dispsemb - structure containing dispersion spectra

function dispsemb = semblance_vphase(rec, spec, procd)

%% This test needs to be revised if still used here:
%% test: replace the records of all receivers with the first one shifted in time
%% proportionally to distance.
%% You should see in the diagram a semblance high at constant velocity given by the
%% third parameter in this call: 

%  rec = test_moveout(rec,dist,0.25);

  % store in dispsemb key information from record

  dispsemb.ffid = rec.ffid;
  dispsemb.line = rec.line;
  dispsemb.vintage = rec.vintage;
  dispsemb.src_stn = rec.src_stn;

  % copy processing parameters into dispsemb structure (for reference in the future)

  dispsemb.phase_vel_expected = procd.phase_vel_expected;
  dispsemb.phase_vel = procd.phase_vel;
  dispsemb.offset_range = procd.offset_range;
  dispsemb.mode_separ = procd.mode_separ;
  dispsemb.freq_min = procd.freq_min;

  [ dispsemb.spacing, dispsemb.freq_range, chind, dispsemb.f, dispsemb.slwns, spec1 ] = semblance_params(rec, spec);

  dispsemb.chans = rec.chan(chind);	% output list of channels

%sf = size(dispsemb.f)		% test printouts
%ss = size(spec1)
%so = size(rec.offset)

%% 3) normalize the spectral amplitudes (keep only the phase factor)

  spec1 = spec1 ./ (abs(spec1)+1.0e-16);

%% 4) for each trial slowness, apply a phase shift to align each record with the first one,
%%	 sum them, and take abs()

  dispsemb.semblance = semblance_vphase1(dispsemb.f,rec.offset(chind),spec1,dispsemb.slwns);

%ds = dispsemb.semblance

%% 5) locate peaks of slownesses and determine their phase velocities

  % calculate a curve to indicate aliasing in p

  dispsemb.p_alias = ones(length(dispsemb.f),1)*max(dispsemb.slwns);	% constant equal max slowness in plot
  p1 = 0.5*dispsemb.f.^(-1)/dispsemb.spacing;

  ind = find(p1 < max(dispsemb.slwns));	% indices of the part within slowness plot range
  dispsemb.p_alias(ind) = p1(ind);

  % find semblance peaks lying below dispsemb.p_alias

  dispsemb.semb_peak = [];		% these will be peaks close to the fundamental mode 
  dispsemb.semb_peak1 = [];		% these will be other peaks

  ind1 = find(dispsemb.f >= dispsemb.freq_min & dispsemb.f <= dispsemb.mode_separ(1));	
						% picking frequencies below the separator
  ind2 = find(dispsemb.f >= dispsemb.freq_min & dispsemb.f > dispsemb.mode_separ(1));	
						% frequencies above the separator

  % locate peaks below separator frequency

  for i=1:length(ind1)

	i1 = ind1(i);

	ind = find(dispsemb.slwns < dispsemb.p_alias(i1));  % slownesses below the aliasing curve

	if ~isempty(ind)

  		[ s, i2 ] = max(dispsemb.semblance(i1,ind));

		dispsemb.semb_peak = [ dispsemb.semb_peak; dispsemb.f(i1), dispsemb.slwns(ind(i2)), s ];
	end
  end

  % locate peaks above separator frequency:   slowness(f) = s(2) - s(3)/(frequency - s(1))

  separ = dispsemb.mode_separ(2) - dispsemb.mode_separ(3)*(dispsemb.f(ind2) - dispsemb.mode_separ(1)).^(-1);

  dispsemb.p_separ = zeros(size(dispsemb.f));		% array for plotting the separator
  dispsemb.p_separ(ind2) = separ;

  for i=1:length(ind2)

	i1 = ind2(i);

	ind = find(dispsemb.slwns < dispsemb.p_alias(i1) & ...
			dispsemb.slwns > separ(i) );	% slownesses below the aliasing curve
							% and above separator
	if ~isempty(ind)				
  		[ s, i2 ] = max(dispsemb.semblance(i1,ind));

		dispsemb.semb_peak = [ dispsemb.semb_peak; dispsemb.f(i1), dispsemb.slwns(ind(i2)), s ];	
	end

	ind = find(dispsemb.slwns < dispsemb.p_alias(i1) & ...
			dispsemb.slwns <= separ(i) );	% slownesses below the aliasing curve
							% and below separator
	if ~isempty(ind)
  		[ s, i2 ] = max(dispsemb.semblance(i1,ind));	

		dispsemb.semb_peak1 = [ dispsemb.semb_peak1; dispsemb.f(i1), dispsemb.slwns(ind(i2)), s ];
  						% these are counted as dispsemb.semb_peak1
	end
  end

%dsp = dispsemb.semb_peak
%dsp1 = dispsemb.semb_peak1

end

