%% Dispersion analysis with (optionally) weighted records
%% =====================================================================
%%
%% Parameters:
%%	freq - column of frequencies in spectra matrix 'spec'
%%	offset - row of offsets in 'spec'
%%	spec - complex spectra of the record (rows are frequencies, columns correspond to offsets)
%%	slowness - array(row) of output slownesses
%%	weight - optional matrix of weights for records at each frequency
%%		(as in 'spec', rows are frequencies, columns correspond to offsets)
%%		Normally, each row of 'weights' should have a sum = 1
%%		If this parameter is not given, all weights are taken equal 1.0/length(offsets)
%% Returns:
%%	dispsemb - dispersion semblance matrix
%%		(rows correspond to frequencies 'freq', columns to slownesses)

function dispsemb = semblance_vphase1(freq, offset, spec, slowness, weight )

  if nargin >= 6				% apply weights
	spec = spec .* weight;
  end

  %% for each trial slowness, apply a phase shift to align each record with the first one,
  %% sum them, and take abs()

  dispsemb = zeros(size(spec,1),length(slowness));	% init
						% due to possibly different time ranges
  two_pi_i_f_d = freq*(2i)*pi*abs(offset);	% matrix of factors in complex exponents

  for i=1:length(slowness)
	phase_shift = exp(two_pi_i_f_d*slowness(i));

	dispsemb(:,i) = abs(mean(spec.*phase_shift,2));
  end

end

