%% Determines source and receiver coordinates using station numbers and
%% optional external functions
%% ====================================================================

%% Parameters:
%%	linepar - nominal line parameters
%%	src_stn - one or multiple source station numbers
%%	src_skid - column of skid values (inline shifts) for each source station in src_stn
%%	src_offset - column of offset values (crossline shifts to the right)
%%		 for each source station in src_stn
%%	rec_stn - one or multiple receiver station numbers
%%
%% Returns:
%%	src_xyz - matrix with rows containing (X,Y,Z) coordinates for each element of src_stn
%%	rec_xyz - matrix with rows containing (X,Y,Z) coordinates for each element of rec_stn
%%	src_x - row of inline coordinates of sources in src_stn 
%%	rec_x - row of inline coordinates of receivers in rec_stn 

function [ src_xyz, rec_xyz, src_x, rec_x ] = set_coords( linepar, src_stn, src_skid, src_offset, rec_stn )

global procdata

  	stn_range = min([ rec_stn, src_stn] ) : max([ rec_stn, src_stn] );

  	if exist('survey_coords.m')
		sxyz = survey_coords(linepar, stn_range);
  	else
		sxyz = survey_coords_def(linepar,stn_range);
  	end

 	%% sort the coordinates by increasing station numbers

  	[~,ind] = sort(sxyz(:,1));

  	sxyz = sxyz(ind,:);

  	%% determine receiver coordinates

  	ind = find(ismember(sxyz(:,1),rec_stn));

  	rec_xyz = sxyz(ind,2:4);

  	%% set in-line receiver coordinates
 
  	rec_x = line_coords( sxyz, rec_stn );

  	%% determine the 3-D and inline coordinates of source points

  	if exist('source_coords.m')

  		srcstn = src_stn + src_skid/linepar(4);  % fractional source station number (temporary variable)

		src_xyz = source_coords(linepar, srcstn);

  		src_x = line_coords( sxyz, srcstn, src_skid, src_offset );
  	else
  		[ src_x, src_xyz ] = line_coords( sxyz, src_stn, src_skid, src_offset ); 
  	end
end

