%% Calculates an STA/LTA ratio section using parameters in 'procdata'
%%
%% For any output sample, the STA/LTA ratio is output for STA window trailing
%% the sample and LTA window leading it. At the end so the time range, the respective
%% window is held in place.
%% =============================================================================
%%
%% Parameters:
%%	data - trace data this matrix 
%%	dt - sampling interval in data
%% Returns:
%%	sta_lta - output STA/LTA section of the same size as 'data'

function sta_lta = stalta(data,dt)

global procdata

  [ nt, nd ] = size(data);	% number of times and traces

  int_st = round(procdata.pick_fb.t_peak/dt);	% number of samples in 'peak' (STA) window

  int_lt = round(procdata.pick_fb.t_prepeak/dt);	% number of samples in LTA window

  % create STA and LTA starting from sample (1+int_lt) and ending with (end-int_st)
	
  s = cumsum(data.^2);

  ind = 1:(nt - int_lt);

  lta = sqrt((s(ind+int_lt,:) - s(ind,:))/int_lt);

  ind = 1:(nt - int_st);

  sta = sqrt((s(ind+int_st,:) - s(ind,:))/int_st);

  % extrapolate LTA with constant values at the beginning

  lta = [ ones(int_lt,1).*lta(1,:); lta ];

  % extrapolate STA with constant values off at the end

  sta = [ sta; ones(int_st,1).*sta(end,:) ];

  sta_lta = sta./lta; 

%sd = size(data)
%ssta_lta = size(sta_lta)

end

