%%  Returns a cosine (Hanning) taper function
%%	For x0 < x1, the taper function is 0 for x < x0 and 1 for x > x1
%%	For x0 > x1, the taper function is 1 for x < x1 and 0 for x > x0

%% Parameters:
%%      x - array of argument for which the function is evaluated
%%      x1 - value of x at which the taper function equals 1
%%      x0 - value of x at which the taper function equals 0
%%  Returns:
%%      taper - taper function corresponding to each argument value in 'x'

function taper = taper_cos( x, x1, x0 )

	taper = zeros(size(x));		% start with zeros

	a = pi/(x1-x0);

	if x0 < x1 
		taper(find(x > x1)) = 1.0;

		ind = find(x > x0 & x < x1);

		taper(ind) = (1.0 - cos((x(ind)-x0)))*0.5; 
	else
		taper(find(x < x1)) = 1.0;

		ind = find(x < x0 & x > x1);

		taper(ind) = (1.0 - cos((x(ind)-x0)))*0.5; 
	end
end


