% Returns the value of basis function at one or multiple depths
%
% Parameters:
%	bftype - string specifying the type of basis function required:
%		'uz', 'ux' (displacement components)
%		'ezz' (or 'ez'), 'exz' (or 'ezx'), 'exx' (or 'ex') (strain components)
%		'szz' (or 'sz'), 'sxz' (or 'szx'), 'sxx' (or 'sx') (stress components)
%	bfnum - array of numbers of the basis function to output
%		If this field is not given or equals [], 
%		all available basis functions are returned.
%	z - depths at which to make output (can be an array)
%
% Returns:
%	bf - 2-D or 3-D (for multiple entries in bfnum) matrix of basis function
%		as stored in structure 'bfun'

function bf = bfun_extract( bftype, bfnum )

global model bfun

  if nargin < 2
	bfnum = [];
  end

  if isempty(bfnum)			% use all basis functions
	bfnum = 1:size(bfun.ux,3);
  end

	% select the basis function

  switch lower(bftype)
	case 'ux'
		bf = bfun.ux(:,:,bfnum);

	case 'uz'
		bf = bfun.uz(:,:,bfnum);

	case { 'ezz', 'ez' }
		bf = bfun.ezz(:,:,bfnum);

	case { 'exz', 'ezx' }
		bf = bfun.exz(:,:,bfnum);

	case { 'exx', 'ex' }
		bf = bfun.exx(:,:,bfnum);

	case { 'szz', 'sz' }
		bf = bfun.szz(:,:,bfnum);

	case { 'sxz', 'szx' }
		bf = bfun.sxz(:,:,bfnum);

	case { 'sxx', 'sx' }
		bf = bfun.sxx(:,:,bfnum);
 
  end

end
