% Returns weights of the basis functions corresponding to spikes at arbitrary depths 
%
% Parameters:
%	bf - the set of basis functions. This variable should contain
%		character string specifying the type of basis function required:
%		'uz', 'ux' (for displacement components)
%		'ezz' (or 'ez'), 'exz' (or 'ezx'), 'exx' (or 'ex') (strain components)
%		'szz' (or 'sz'), 'sxz' (or 'szx'), 'sxx' (or 'sx') (stress components).
%	bfnum - number of the basis function
%	z - array of depths of the spikes

% Returns:
%	c - matrix of weights of the basis functions representing spikes at depths in 'z'.
%		Each column of this matrix is a model vector corresponding one value in array z.
%		the number of columns in this function equals length(z)

function c = bfun_spike( bf, z )

global model bfun

  c = zeros(model.num_modes_PSV,length(z));		% output columns of c

  % obtain values of each basis function at each depth in z
 
  bfv = conj(bfun_value( bf, 1:model.num_modes_PSV, reshape(z,1,[]) ));

  % calculate the inverse norm matrix

  switch lower(bf)
	case { 'ux', 'uz' }
		bfinv = inv(inv_norm('uz','ux')); 

	case { 'ezz', 'ez' }
		bfinv = inv(inv_norm('ez','ex','ezx')); 

	case { 'szz', 'sz' }
		bfinv = inv(inv_norm('sz','sx','szx')); 
  end

  % go through all z values and and fill the corresponding columns in c

  for k=1:length(z)
    for j = 1:size(bfv,3)

	c(j,k) = bfv(1,k,j);

    end		% for j
  end		% for k

  % finalize the vectors

  c = bfinv * c;

end

