% Returns the value of observable field at multiple depths
%
% Parameters:
%	bf - the set of basis functions. This variable can be given in two ways:
%		1) By a character string specifying the type of basis function required:
%		'uz', 'ux' (for displacement components)
%		'ezz' (or 'ez'), 'exz' (or 'ezx'), 'exx' (or 'ex') (strain components)
%		'szz' (or 'sz'), 'sxz' (or 'szx'), 'sxx' (or 'sx') (stress components);
%		2) directly by one of the 3-D matrices bfun.uz, bfun.ux, bfun.ezz, bfun.exx, etc.
%	c - vector (column) of factors with which each  basis function contributes to the
%		field. The size of this column must match the number of basis functions
%		(i.e., size(c,1) == size(bfun.uz,3))
%	z - depths at which to make output (can be a 1-D array)

% Returns:
%	v - matrix of values of the field at level(s) in 'z'. Its rows correspond to depth levels
%%		and columns to the columns in 'c', i.e. the size(c) is [ length(z), size(c,2) ]

function v = field_value( bf, c, z )

global model bfun

  z = reshape(z,[],1);		% reshape z to one column
  nc = size(c,2);

  v = zeros(length(z),nc);		% output section

  bfv = bfun_value( bf, [], z );	% basis functions for all z

%sbfv = size(bfv)	% tests
%sz = size(z)
%sc = size(c)

  for j=1:nc
    for k=1:size(c,1)
	v(:,j) = v(:,j) + bfv(:,1,k)*c(k,j);
    end
  end
end

