%% File name for model data in Matlab format
%%
%% If optional parameter verno is positive, .mod file name containing 'verno' 
%% value is returned. Otherwise, '.mat' file name is returned.
%% ===========================================================================

%% Parameters:
%%	line_no - line number
%%	vintage - vintage number for the model
%%	ID - location of the model (1 or 15 in the present experiment)
%%	verno - optional version number. If thsi number is > 0
%%		'.mod' file name is returned instead of teh default '.mat' file
%% Returns:
%%	matfile - name of .mat or .mod file in which the model and modes are saved

function matfile = filename_model( line_no, vintage, ID, verno )

  if nargin < 4
	verno = 0;
  end

  matfile = sprintf('interp/model_l%04d_v%05d_id%05d',line_no,vintage,ID);

  if verno > 0		% archiving file name
	matfile = sprintf('%s_a%d.mod',matfile,verno);
  else			% default file name for current model
	matfile = [ matfile '.mat' ];
  end
end


