%% Returns the diagonal of matrix dJ/dm 
%% (factor in the data-misfit related part iof Hessian)
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	mode_num - number of mode of the data (0 - fundamental, 1, 2 - overtones)
%%		if this parameter is not specified, all available modes are used  
%% Returns:
%%	dJdm - matrix of dJ/dm for the data 
%%		(rows are model layers, columns are data points)
%% ================================================================================

function dJdm = inv_dJdm(mode_num)

global inversion

  if nargin < 1		% no mode given
	mode_num = [];
  end
  
  if isempty(mode_num)
	dJdm = [ inv_dJdm(0), inv_dJdm(1), inv_dJdm(2) ];

	return
  end

  switch mode_num
	case 0
	  if ~isempty(inversion.data0)
		dJdm = inversion.v_d2(:,inversion.data0(:,1),1);
		return
	  end

	case 1
	  if ~isempty(inversion.data1)
		dJdm = inversion.v_d2(:,inversion.data1(:,1),2);
		return
	  end

	case 2
	  if ~isempty(inversion.data2)
		dJdm = inversion.v_d2(:,inversion.data2(:,1),3);
		return
	  end

	otherwise
  end

  dJdm = [];	% no data - no matrix

end

