%% Prepares input phase-velocity data for inversion by resampling it
%% onto the grid inversion.kx
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	data - input data in the form of two columns: frequencies and velocities.
%%		Rows are data points.
%% Returns:
%%	outdata - the same 'data' resampled to the values of inversion.kx.
%%		each row of 'outdata' contains:
%%		column 1: index in array inversion.kx (also column index in the 
%%				matrices of gradients)
%%		column 2: frequency
%%		column 3: data (usually phase velocity)
%%
%% ================================================================================

function outdata = inv_data(data)

global inversion

  if isempty(data)
	outdata = [];
	return
  end

  kx = data(:,1)./data(:,2)*2*pi;	% kx in 'data'

  kxi = reshape(inversion.kx,[],1);	% column of kx

  f = interp1(kx,data(:,1),kxi);	% interpolate frequency onto the common inversion.kx
  v = interp1(kx,data(:,2),kxi);	% interpolate vel. onto the common inversion.kx

  ind = find(isfinite(v));	% indices of matching values in inversion.kx

  if isempty(ind)
	outdata = [];
	return
  end

  outdata = [ ind, f(ind,1), v(ind,1) ];

end

