%% Returns the vector of velocity data misfit for one wave mode
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	par - column of scaling factors for the model. If this parameter equals [],
%%		values par(i) = 1 are used
%%	mode_num - number of mode of the data (0 - fundamental, 1, 2 - overtones)
%%		if this parameter is not specified or data are empty, 
%%		data error for all available modes is returned 
%% Returns:
%%	dd - column vector of data error (data - data_predicted) for this mode
%% ================================================================================

function dd = inv_data_misfit(par,mode_num)

global model inversion

  if nargin < 1		% no par given
	par = [];
  end

  if isempty(par)	
	par = ones(model.nlayers,1);
  end

  if nargin < 2		% no mode given
	mode_num = [];
  end
  
  if isempty(mode_num)
	dd = [ 	inv_data_misfit(par,0)
		inv_data_misfit(par,1)
		inv_data_misfit(par,2) ];

	return
  end

  switch mode_num
	case 0
	  if ~isempty(inversion.data0)
		dd = inversion.data0(:,3) - inv_data_pred(par,0);
		return
	  end

	case 1
	  if ~isempty(inversion.data1)
		dd = inversion.data1(:,3) - inv_data_pred(par,1);
		return
	  end

	case 2
	  if ~isempty(inversion.data2)
		dd = inversion.data2(:,3) - inv_data_pred(par,2);
		return
	  end

	otherwise
  end

  dd = [];	% no data - no misfit

end

