%% For model perturbation 'par', 
%% returns predicted data value based on the precomputed data, derivative, 
%% and second derivative values at par = 1
%% -------------------------------------------------------------------------
%% 
%% Parameters:
%%	par - column of scaling factors for the model. If this parameter equals [],
%%		values par(i) = 1 are used
%%	mode_num - number of mode of the data (0 - fundamental, 1, 2 - overtones)
%%		if this parameter is not specified, all available modes are used  
%% Returns:
%%	d - column of predicted data values at 'par'
%% ================================================================================

function d = inv_data_pred(par,mode_num)

global model inversion

  if nargin < 1		% no par given
	par = [];
  end

  if isempty(par)	
	par = ones(model.nlayers,1);
  end

  if nargin < 2		% no mode given
	mode_num = [];
  end
  
  if isempty(mode_num)
	d = [ 	inv_data_pred(par,0)
		inv_data_pred(par,1)
		inv_data_pred(par,2) ];

	return
  end

  switch mode_num
	case 0
	  if ~isempty(inversion.data0)
		v = transpose(inversion.v(1,inversion.data0(:,1)));
		vd = transpose(inversion.v_d(:,inversion.data0(:,1),1));
		vd2 = transpose(inversion.v_d2(:,inversion.data0(:,1),1));

  		d = inv_dpred1(v,vd,vd2,par);
		return
	  end

	case 1
	  if ~isempty(inversion.data1)
		v = transpose(inversion.v(2,inversion.data1(:,1)));
		vd = transpose(inversion.v_d(:,inversion.data1(:,1),2));
		vd2 = transpose(inversion.v_d2(:,inversion.data1(:,1),2));

  		d = inv_dpred1(v,vd,vd2,par);
		return
	  end

	case 2
	  if ~isempty(inversion.data2)
		v = transpose(inversion.v(3,inversion.data2(:,1)));
		vd = transpose(inversion.v_d(:,inversion.data2(:,1),2));
		vd2 = transpose(inversion.v_d2(:,inversion.data2(:,1),2));

  		d = inv_dpred1(v,vd,vd2,par);
		return
	  end
  end

  d = [];	% no data - no misfit

end

