%% Returns the vector 'g' (gradient of objective function) for iterative inverse
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	par - column of scaling factors for the model. If this parameter equals [],
%%		values par(i) = 1 are used
%%	mode_num - number of mode of the data (0 - fundamental, 1, 2 - overtones)
%%		if this parameter is not specified, all available modes are used  
%% Returns:
%%	g - column vector of the gradient (one value per layer)
%% ================================================================================

function g = inv_gradient(par,mode_num)

global inversion

  if isempty(par)	
	par = ones(model.nlayers,1);
  end

  nl = size(inversion.v_d,1);	% number of layers; take it from vphase_d
				% to ensure that Jacobian has been calculated

  if nargin >= 2	% mode_num given

	g = -transpose(inv_jacobian(par,mode_num))*inv_data_misfit(par,mode_num);

	return
  end

  g = zeros(nl,1);

  % if got here, mode_num is not given - sum all three

  if ~isempty(inversion.data0)
	g = g + inv_gradient(par,0);
  end

  if ~isempty(inversion.data1)
	g = g + inv_gradient(par,1)*inversion.data_weight(1);
  end

  if ~isempty(inversion.data1)
	g = g + inv_gradient(par,2)*inversion.data_weight(2);
  end

end

