%% Returns the Hessian matrix for iterative inverse
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	par - column of scaling factors for the model. If this parameter equals [],
%%		values par(i) = 1 are used
%%	mode_num - number of mode of the data (0 - fundamental, 1, 2 - overtones)
%%		if this parameter is not specified, all available modes are used  
%% Returns:
%%	H - Hessian matrix (one row and one column per layer)
%% ================================================================================

function H = inv_hessian(par,mode_num)

global model inversion

  if nargin < 1		% no par given
	par = [];
  end

  if isempty(par)	
	par = ones(model.nlayers,1);
  end

  if nargin < 2		% no mode given
	mode_num = [];
  end

  J = inv_jacobian(par,mode_num);		% simplified Hessian

  H = transpose(J)*J + diag(inv_dJdm(mode_num)*inv_data_misfit(par,mode_num));

end

