%% Returns the vector 'g' (gradient of objective function) for iterative inverse
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	par - column of scaling factors for the model. If this parameter equals [],
%%		values par(i) = 1 are used
%%	mode_num - number of mode of the data (0 - fundamental, 1, 2 - overtones)
%%		if this parameter is not specified, all available modes are used  
%% Returns:
%%	J - matrix of Jacobian for the data 
%%		(rows are data points, columns are model layers)
%% ================================================================================

function J = inv_jacobian(par,mode_num)

global model inversion

  if nargin < 1		% no par given
	par = [];
  end

  if isempty(par)	
	par = ones(model.nlayers,1);
  end

  if nargin < 2		% no mode given
	mode_num = [];
  end
  
  if isempty(mode_num)
	J = [ 	inv_jacobian(par,0)
		inv_jacobian(par,1)
		inv_jacobian(par,2) ];

	return
  end

  switch mode_num
	case 0
	  if ~isempty(inversion.data0)
		J = transpose(inversion.v_d(:,inversion.data0(:,1),1)) + ...
			transpose(inversion.v_d2(:,inversion.data0(:,1),1).*(par-1));
		return
	  end

	case 1
	  if ~isempty(inversion.data1)
		J = transpose(inversion.v_d(:,inversion.data1(:,1),2)) + ...
			transpose(inversion.v_d2(:,inversion.data0(:,1),2).*(par-1));
		return
	  end

	case 2
	  if ~isempty(inversion.data2)
		J = transpose(inversion.v_d(:,inversion.data2(:,1),3)) + ...
			transpose(inversion.v_d2(:,inversion.data2(:,1),3).*(par-1));
		return
	  end

	otherwise
  end

  J = [];	% no data - no J

end

