%% Updates the model based on gradients calculated by inv_perturb()
%% -------------------------------------------------------------------------
%% 
%% Parameters:
%%	modes_fun - name of the function modeling wavemodes,
%%		for example @modes_rayleigh. This function should take a vector
%%		of kx and return columns of frequencies and phase 
%%	step_fun - name of the function performing stepping,
%%		for example @inv_newton. This function should take a column of parameters 'par' 
%%		and return a column of their updates
%%	niter - number of iterations without recalculating the linearized kernels
%% ================================================================================

function inv_step(modes_fun, step_fun, niter)

global model inversion

  if nargin < 3		% niter not given
	niter = 5;
  end

  % recalculate data and kernels

  inv_perturb(modes_fun);		

  par = ones(model.nlayers,1);

  % make several iterations without recalculating the kernels

  for i=1:niter
  	par = par + step_fun(par);	% update 'par' factors 

	% update model

	if i == niter		% final for this step

		scale_model0(par);
		par = 1;
	else			% otherwise keep the '0' model
		scale_model(par);
	end
  end

end

