%% Returns list of model versions (integer numbers) available for the
%% model given by line number, vintage, and location ID
%%
%% Parameters:
%%	line_no - line number
%%	vintage - vintage number for the model
%%	ID - location of the model (1 or 15 in the present experiment)
%%
%% Returns:
%%	lst - array of integer version numbers (0 is the current operational
%%		model in interp/model*.mat file, values > 0 are saved versions
%%	filename_lst - list of file names corresponding to numbers in 'lst'
%%
%% ========================================================================

function [ lst, filename_lst ] = list_model(line_no, vintage, ID )

  % main model is in the list if the file exists:

  fn = filename_model( line_no, vintage, ID);

  if exist(fn)
  	filename_lst = { fn };
  	lst = [ 0 ];
  else
  	filename_lst = {};
  	lst = [];
  end

  % list all '.mod' files and obtain the needed ones by matching

  modfiles = list_files( 'interp/', '.mod' );

  i1 = strfind(fn,'/');
  i2 = strfind(fn,'.mat');

  d = fn(1:i1);		% path; this should always equal 'interp/', but keeping general all the same

  fn = fn((i1+1):(i2-1));	% strip the directory and '.mat' off
  lfn = length(fn);

  for i=1:size(modfiles,1)
 
	if strncmp(modfiles(i,:),fn,lfn)	% .mod file matches the .mat file

		n = str2num(modfiles(i,(lfn+3):end));	% skipping '_a' and reading archive number

		lst(length(lst)+1) = n;
		filename_lst{length(filename_lst)+1} = [ d, strtrim(modfiles(i,:)), '.mod' ];
	end
  end

  % sort the files by increasing version numbers

  [ lst, ind ] = sort(lst);

  filename_lst = filename_lst(ind);

%lst
%filename_lst

end

