%%%%%%%%%% P-SV wave reflection modeling and inversion in a layered medium
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear

% You can keep several (optional) versions of the model .
% Edit, for example, 'model_2' and/or create other models for comparison

% Columns of these matrices are:
%	1) depth to the bottom of layer (m)
%	2) density
%	3) P-wave velocity (m/ms or km/s)
%	4) S-wave velocity
%	5) bulk viscosity
%	6) shear viscosity

model_2 = [
	0.5,	1.53,	0.192,	0.096,	0.0	0.0		
	2.0,	1.53,	0.222,	0.111,	0.0	0.0			
	5.0,	1.13,	0.232,	0.116,	0.0	0.0	
	8.0,	1.13,	0.242,	0.121,	0.0	0.0	
	15.0,	1.13,	0.3,	0.15,	0.0	0.0	
	35.0,	1.53,	0.3,	0.15,	0.0	0.0
];

% use several global variables for data exchange between functions 
% and their interactive inspection:
 
global model bfun freq vphase vgroup

% Set up global 'model' using the velocity-density columns above:

set_model(model_2);

% Set up modeling for a given horizontal wavenumber. For example, for
% wavenumber 0.1 (1/m), construct the basis functions in the model:  

basis_rayleigh(0.1);

% The following calls can be used for preliminary testing. 
% They are not required for subsequent modeling:

plot_bfun_PSV();	% plot basis functions for wavelength 1 m 

plot_MSD_PSV();		% plot M, S, and D matrices

	% plot a section of uz for a wave traveling at 1 m/ms downward

z = linspace(model.z0,10,20);	% 20 points to the depth of 20 m,
				% (this is where layering ends in the current model)
				% Change these parameters to match your model!			

c = bfun_spike('uz',z );	
		% for each level 'z(i)', this creates a model vector in 'c(:,i)' 
		% containing a decomposition of a unit spike at depth z(i)
		% in terms of the basis functions bfun.uz

plot_c(c);	% test plot showing scaled values of c for different wave mode numbers

figure(2);
	
plot_field('uz',c)	% plot uz wavefield of the decomposed spikes 

% Begin reflection modeling tests
% ==============================================================================

% The results will be placed in global structure 'bfun' (type its name and
% view contents).
% In particular, the current wavenumber will be in field bfun.kx

[ M, S, D ] = energy_forms_PSV()

% Form a starting model, for example, a spike of vertical displacement at the
% top of the model:

c = bfun_spike('uz',z );

% you can see how it looks like in this plot:

plot_field('uz',c)

% Your task is now to write function 'time_step()' (or create your own name)
% for time stepping of field 'c'.
% ----------------------------------------------------------------------------
%
% Select a correct value for time step and number of steps you want to model!
% in this example, the field vector from every new time step will be added to
% matrix 'c':

dt = 0.1;		

for i=2:100
	c(:,i) = time_step(c(:,i-1),dt);
end

% Maybe you will need to select a smaller time step and save 'c' not after every step 
% but after a series of them. Explore these options, make plots, talk to Wubing. 
 
% plot the propagating field

plot_field('uz',c)	%  uz (vertical displacement)
plot_field('ux',c)	%  ux (horizontal displacement)

plot_field('ezz',c)	%  examples of plotting components of strain
plot_field('exx',c)	%  
plot_field('ezx',c)	%  

plot_field('szz',c)	%  examples of plotting components of stress
plot_field('sxx',c)	%  
plot_field('szx',c)	%  
