%% Modify global 'model' by depth-interpolating values provided in matrix 'layers'
%%
%% Parameters:
%%	layers - layer parameter matrix with columns:
%%			1) depth to the bottom of layer
%%			2) density
%%			3) P-wave velocity
%%			4) S-wave velocity
%%			5) P-wave viscosity
%%			6) S-wave viscosity
%%	ind - index specifying what item to modify (values 1-6 above)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function modify_model(layers, ind )

global model

  etas = model.eta_mu;
  etap = model.eta_lambda + 2.0/3.0 * model.eta_mu;

  switch ind		% depths and depth increments
	case 1
		n = min(model.nlayers,size(layers,1));		% number of layers to change

  		model.z(1:n,1) = layers(1:n,1);

  		model.dz = [ layers(1,1)-model.z0; layers(2:end,1)-layers(1:(end-1),1) ]; 

	case 2		% density

		model.rho = interp1(layers(:,1),layers(:,2),model.z,'linear','extrap');

	case 3		% Vp

		model.vp = interp1(layers(:,1),layers(:,3),model.z,'linear','extrap');

	case 4		% Vs

		model.vs = interp1(layers(:,1),layers(:,4),model.z,'linear','extrap');

	case 5		% etap

		etap = interp1(layers(:,1),layers(:,5),model.z,'linear','extrap');

	case 6		% etas

		etas = interp1(layers(:,1),layers(:,6),model.z,'linear','extrap');
  end

  model.mu = model.vs.^2 .* model.rho;
  model.lambda = model.vp.^2 .* model.rho - 2.0 * model.mu;
  model.l2mu = model.lambda + 2.0*model.mu;

  model.eta_mu = etas;					% shear viscosity
  model.eta_lambda = etap - 2.0/3.0 * model.eta_mu;	% lambda-type viscosity

  set_model0();		% finalize

end

