%% Plots the current model and PSV basis functions 

function plot_bfun_PSV()

global model bfun

  % evaluate the wavelength for plot labels

  lambda = 2*pi/bfun.kx;

  % gain factor for plotting basis functions

  gain = 0.5;

  z = linspace(model.z0,model.z(end),400);	% grid for plotting basis functions
  
  sepbf = [ 0, size(bfun.uz,3)+0.5 ];	% horizontal extent in basis functions

  % plot

  figure(1);
  clf
  subplot(2,3,1)

  plot_model();		% this also plots axes labels

  title("Model")

  subplot(2,3,2)
  hold on

	% draw yellow lines separating layers

  plot(sepbf,[ model.z0, model.z0 ],'y-');

  for i=1:model.nlayers
	plot(sepbf,[ model.z(i,1), model.z(i,1) ],'y-');
  end

  for i=1:size(bfun.uz,3)
	base = i;		% shift of the basis function in the plot

	uz = bfun_value( 'uz', i, z );

	uz = uz/(max(abs(uz))+1.0e-8)*gain;	% normalize to peak value = 1

  	plot([base base],[ model.z0, model.z(end,1) ],'g-');

	if mod(i,2) == 1
 		plot(uz+base,z,'b-');
	else
 		plot(uz+base,z,'r-');
	end
  end

  set(gca,"Ydir","reverse","XTick",[1:size(bfun.uz,3)])
  xlabel("Basis function")
  ylabel("z (m)")
  title(sprintf("Uz for wavelength = %1.2f m",lambda))

  subplot(2,3,3);
  hold on

	% draw yellow lines separating layers

  plot(sepbf,[ model.z0, model.z0 ],'y-');

  for i=1:model.nlayers
	plot(sepbf,[ model.z(i,1), model.z(i,1) ],'y-');
  end

  for i=1:size(bfun.ux,3)
	base = i;		% shift of the basis function in the plot

	ux = bfun_value( 'ux', i, z );

	ux = ux/(max(abs(ux))+1.0e-8)*gain;	% normalize to peak value = 1

  	plot([base base],[ model.z0, model.z(end,1) ],'g-');

	if mod(i,2) == 1
 		plot(real(ux)+base,z,'b-');
	else
 		plot(real(ux)+base,z,'r-');
	end
  end

  set(gca,"Ydir","reverse","XTick",[1:size(bfun.uz,3)])
  xlabel("Basis function")
  ylabel("z (m)")
  title(sprintf("Ux for wavelength = %1.2f m",lambda))

  subplot(2,3,5)
  hold on

	% draw yellow lines separating layers

  plot(sepbf,[ model.z0, model.z0 ],'y-');

  for i=1:model.nlayers
	plot(sepbf,[ model.z(i,1), model.z(i,1) ],'y-');
  end

  for i=1:size(bfun.uz,3)
	base = i;		% shift of the basis function in the plot

	szz = bfun_value( 'sz', i, z );

	szz = szz/(max(abs(szz))+1.0e-8)*gain;	% normalize to peak value = 1

  	plot([base base],[ model.z0, model.z(end,1) ],'g-');

	if mod(i,2) == 1
 		plot(real(szz)+base,z,'b-');
	else
 		plot(real(szz)+base,z,'r-');
	end
  end

  set(gca,"Ydir","reverse","XTick",[1:size(bfun.uz,3)])
  xlabel("Basis function")
  ylabel("z (m)")
  title(sprintf("szz for wavelength = %1.2f m",lambda))

  subplot(2,3,6)
  hold on

	% draw yellow lines separating layers

  plot(sepbf,[ model.z0, model.z0 ],'y-');

  for i=1:model.nlayers
	plot(sepbf,[ model.z(i,1), model.z(i,1) ],'y-');
  end

  for i=1:size(bfun.uz,3)
	base = i;		% shift of the basis function in the plot

	sxz = bfun_value( 'sx', i, z );

	sxz = sxz/(max(abs(sxz))+1.0e-8)*gain;	% normalize to peak value = 1

  	plot([base base],[ model.z0, model.z(end,1) ],'g-');

	if mod(i,2) == 1
 		plot(real(sxz)+base,z,'b-');
	else
 		plot(real(sxz)+base,z,'r-');
	end
  end

  set(gca,"Ydir","reverse","XTick",[1:size(bfun.uz,3)])
  xlabel("Basis function")
  ylabel("z (m)")
  title(sprintf("sxz for wavelength = %1.2f m",lambda))
% axis ([0 100 -5 10]);

end

