%% For a current set of basis functions in global 'bfun',
%% plots in current figure a section of depth distribution of the real part of 
%% the field
%%
%% Parameters:
%%	bf - the set of basis functions. This variable can be given in two ways:
%%		1) By a character string specifying the type of basis function required:
%%		'uz', 'ux' (for displacement components)
%%		'ezz' (or 'ez'), 'exz' (or 'ezx'), 'exx' (or 'ex') (strain components)
%%		'szz' (or 'sz'), 'sxz' (or 'szx'), 'sxx' (or 'sx') (stress components);
%%		2) directly by one of the 3-D matrices bfun.uz, bfun.ux, bfun.ezz, bfun.exx, etc.
%%	c - model vector, i.e. array of weights for each of the basis functions in 'bf'. For multiple
%%		entries in 'c', the corresponding records are plotted as a seismic section, with
%%		'c' values spanning the horizontal axis of the plot, and z plotted downward

function plot_field( bf, c )

global model bfun

  z = linspace(model.z0,model.z(end),400);	% depth grid for plotting

  % extract depth columns for each column in 'c'

  section = field_value( bf, c, z );

  % gain factor for plotting basis functions

  gain = 0.5;

  % plot

  hold on

  nc = size(section,2);

  for i=1:nc
	v = real(section(:,i));

	v = v/(max(abs(v))+1.0e-8)*gain;	% normalize to peak value = 1

  	plot(v+i,z,'b-');
  end

  set(gca,"Ydir","reverse","XTick",1:nc)
  xlabel("column(c)")
  ylabel("z (m)")

  if ischar(bf)
	title(["Field " bf " mapped in vector c" ])
  else
  	title("Field mapped in vector c")
  end
end

