%% Add plots of current model in current figure
%% Parameters:
%%	 codes - string containing codes for the items to plot
%%		for example, 'psl':
%%		's' - plot S wave velocity profile in red
%%		'p' - plot P wave velocity profile in blue
%%		'l' - plot layer separators P in yellow

%% Returns:
%%	h = cell array of handles for all lines 
%% ==============================================

function h = plot_model1(codes)

global model

  hold on

  h = {};

  codes = lower(codes);

  [zp,vp] = plot_layers(model.z,model.vp);
  [zs,vs] = plot_layers(model.z,model.vs);

	% draw yellow lines separating layers

  if ~isempty(strfind(codes,'l'))
  	sep = [ min(model.vs)*0.9, max(model.vp)*1.05 ];	% horizontal extent of model

  	h{length(h)+1} = line(sep,[ model.z0, model.z0 ],'LineStyle','-','Color','y');

  	for i=1:model.nlayers
		h{length(h)+1} = line(sep,[ model.z(i,1), model.z(i,1) ],'LineStyle','-','Color','y');
  	end
  end

  if ~isempty(strfind(codes,'p'))
  	h{length(h)+1} = line(vp,zp,'LineStyle','-','Color','b');
  end

  if ~isempty(strfind(codes,'s'))
  	h{length(h)+1} = line(vs,zs,'LineStyle','-','Color','r');
  end

end

