%% Plots model attribute in current figure

%% Parameters:
%%	line_no - line number
%%	vintage - vintage number for the model
%%	ID - location of the model (1 or 15 in the present experiment)
%% 	attr - name of the attribute to plot (case insensitive):
%%		'rho' - density
%%		'Vp' or 'Vs' - P- or S-wave velocities
%%		'K' - bulk modulus
%%		'mu' or 'G' - shear modulus
%%	linestyle - line style string
%%	label - label of plotted item appended to the legend 'L'
%%	L - cell array of legends

%% Returns:
%%	L_new - cell arrays h and L with appended parameters 
%%		of plotted lines
%% ===========================================================================

function L_new = plot_model_attr(line_no, vintage, ID, attr, linestyle, label, L)

global model

  L_new = L;

  matfile = filename_model( line_no, vintage, ID );

  if ~exist(matfile)
	disp(sprintf('*** No model for Line %d, ID %d, Vintage %d', line_no, ID, vintage ))
  	return
  end

  load(matfile);

  [zp,vp] = plot_layers(model.z,model.vp);
  [zs,vs] = plot_layers(model.z,model.vs);
  [zr,rho] = plot_layers(model.z,model.rho);

  hold on
  grid on

  switch lower(attr)

	case 'rho'
  		plot(rho,zp,linestyle);

  		xlabel("Density (g/cm3)")

	case 'vp'
  		plot(vp,zp,linestyle);

  		xlabel("Vp (m/ms)")

	case 'vs'
  		plot(vs,zs,linestyle);

  		xlabel("Vs (m/ms)")

	case 'k'

		k = rho.*(vp.^2-4/3*vs.^2)*1000;

  		plot(k,zs,linestyle);
  		xlabel("Small-strain bulk modulus (MPa)")

	case { 'mu', 'g' }

		mu = (rho.*vs.^2)*1000;

  		plot(mu,zs,linestyle);
  		xlabel("Small-strain shear modulus (MPa)")
  end
	
  L_new{length(L_new)+1} = label;	% append label to legend

  set(gca,'YDir','reverse')

  ylabel("z (m)")

end

