%%% plotting the phase velocities of modes modeled by modes_rayleigh.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Parameters:
%%	freq - matrix of frequencies for all modes as in 'modes' structure 
%%		returned by modes_rayleigh()
%%	vel - matrix of mode velocities as returned by modes_rayleigh() 
%%	nmodes - maximum number of modes to plot. 
%%		If this number is not given, 6 modes are plotted.
%%	figure_no - number of the figure to which the plotting commands are added 
%%		if this parameter is not given, current figure is used
%%	num_panes - this value can be 3 or 4, which is teh number of plot panels to show.
%%		With num_panes = 4, an additional plot of slowness vs. wavenyumber kx is displayed

function plot_model_modes( freq, vel, disp, nmodes, figure_no, num_panes )

global procdata

  if nargin < 3			% dispersion structure not given
	disp = [];
  end

  if nargin < 4			% nmodes not given
	nmodes = 6;
  else
	if isempty(nmodes)
		nmodes=6;
	end
  end

  if nargin < 5			% figure number not given
	figure_no = gcf();
  end

  if nargin < 6			% figure number not given
	num_panes = 3;
  end

  if ~ismember(num_panes, [ 3, 4 ] )
	num_panes = 3;
  end

  nm = size(freq,1);

  if nmodes > nm
	nmodes = nm;
  end

  slwns = vel.^(-1);

  figure(figure_no)

  subplot(1,num_panes,1)	% model plot
  hold on

  % plot picks remapped into pseudodepth

  if ~isempty(disp)
  	if ~isempty(disp.semb_peak)
		z = (disp.semb_peak(:,2).*disp.semb_peak(:,1)).^(-1)/2;		% pseudodepth
		v = disp.semb_peak(:,2).^(-1)*procdata.Vs;

  		plot(v,z,'kx')
  	end
  end

  plot_model();		% this also plots axes labels

  % also plot the modeled velocities scaled into Vs and versus pseudo-depth z = wavelength/2

  for i=1:nmodes

	z = vel(i,:)./freq(i,:)*procdata.pseudodepth;	% pseudodepth
	v = vel(i,:)*procdata.Vs;	

	plot(v, z, '-k');

	% mark mode number

	text(v(end), z(end),num2str(i));
  end

  title("Layers and model")

  subplot(1,num_panes,3)		% phase velocity plot
  hold on

  for i=1:nmodes

	plot(freq(i,:),vel(i,:),'-k');

	% mark mode number

	text(freq(i,end),vel(i,end),num2str(i));
  end

%plot(phvel_data_1(:,1),phvel_data_1(:,2),';obs 1;');	

  plot_axes('Phase velocities','fv',[],[0, 0.6])

  subplot(1,num_panes,2)		% phase slowness plot
  hold on

  if ~isempty(disp)
	plot_semblance1(disp)
  end

  for i=1:nmodes

	plot(freq(i,:),slwns(i,:),'-k');

	% mark mode number

	text(freq(i,1),slwns(i,1),num2str(i));
  end

  xlabel('Frequency (Hz)')
  ylabel('Slowness (ms/m)')
  title("Phase slownesses")

  if num_panes > 3

  	subplot(1,num_panes,4)		% phase slowness vs. kx
  	hold on

  	for i=1:nmodes

		plot(freq(i,:).*slwns(i,:)*2*pi,slwns(i,:),'-k');

		% mark mode number

		text(freq(i,1),slwns(i,1),num2str(i));
  	end

  	xlabel('kx (1/m)')
  	ylabel('Slowness (ms/m)')
  	title("Phase slownesses")
  end

end

