%% Modify velocities in current model so that Vp and Vs in the layer containing depth z are
%% scaled by factor Vs/Vs_in_reference_mode)
%%
%% Parameters:
%%      z - depth level at which the scaling is applied
%%	Vs - target value for S-wave velocity at this depth
%%	ref_mode - (optional, default = 1) - number of the reference mode used for
%%		estimating pseudo S-wave velocity
%%
%% Returns:
%%	layer - number of layer which was scaled

function layer = scale_model_fVs(z, Vs, ref_mode)

global procdata model modes

	% do not scale if target point is above the model

	if z < model.z0
		return
	end

	if nargin < 3
		ref_mode = 1;
	end

	nmodes = size(modes.freq,1);

	if ref_mode > nmodes
		ref_mode = nmodes;
	end

	nlayers = size(model.vs,1);

	par = ones(nlayers,1);		% default scaling parameters

	z0 = modes.vphase(ref_mode,:)./modes.freq(ref_mode,:)*procdata.pseudodepth;	% pseudodepths of ref_mode

	v0 = interp1(z0,modes.vphase(ref_mode,:),z-model.z0,'linear','extrap')*procdata.Vs;  % pseudo-Vs of ref_mode 

	ind = find(model.z >= z);	% first entry will be the index of layer to modify

	if isempty(ind)
		ind = nlayers;
	end

%mz = model.z
%z
%ind
%z0
%v0
%Vs

	layer = ind(1);

	par(layer,1) = Vs/v0;

%par

  	scale_model(par,true);	% scaling relative to current model
end

