% Returns polynomial coefficients of strain components due to 
% the specified components of displacement
%
% Parameters:
%	layer - layer number for which calculation is performed
%	kx - horizontal wavenumber
% 	uz, ux - polynomial expansions of vertical and horizontal components of displacement
%
% Returns:
%	e_uz - polynomial coefficients of components of strain caused by uz alone.
%		Three rows of this matrix correspond to zz, xz, and xx components
%		of stress
%	e_ux - polynomial coefficients of the components of strain caused by ux alone.
%		Three rows of this matrix correspond to zz, xz, and xx components
%		of stress
 
function [ e_uz, e_ux ] = strain( layer, kx, uz, ux )

global model 

%layer

  ddz = 1.0/model.dz(layer,1);		% factors for differentiation
  ddx = 1i*kx;

  zero = zeros(size(uz));

  % calculate polynomial representation of derivatives padded to four coefficients
  % (it turns out that Matlab and Octave return different numbers of coefficients
  % if the leading coefficients equal zero) 

  nc = size(zero,2);		% number of coeffs needed

  duz = polyder(uz)*ddz;
  n = length(duz);

  e_uz = [ 	zeros(1,nc-n), duz	% zz component, pad with missing zeros on the left
		uz*ddx*0.5		% xz component
		zero	];		% xx component

  dux = polyder(ux)*ddz*0.5;
  n = length(dux);

  e_ux = [ 	zero
		zeros(1,nc-n), dux	% pad with missing zeros on the left
		ux*ddx	];

%uz
%ux
%p = polyder(uz)
%ddz
%ddx
%e_uz
%e_ux

end

