% Returns polynomial coefficients of stress components due to 
% the specified components of displacement
%
% Parameters:
%	layer - layer number for which calculation is performed
%	kx - horizontal wavenumber
% 	uz, ux - polynomial expansions of vertical and horizontal components of displacement
%	zeta - if this argument is given, output polynomial coefficients are replaced with
%		values of stress components 
%
% Returns:
%	s_uz - polynomial coefficients (or values if parameter 'zeta' is given) 
%		of the components of stress caused by uz alone.
%		Three rows of this matrix correspond to zz, xz, and xx components
%		of stress.
%	s_ux - polynomial coefficients (or values if parameter 'zeta' is given)
%		of the components of stress caused by ux alone.
%		Three rows of this matrix correspond to zz, xz, and xx components
%		of stress
 
function [ s_uz, s_ux ] = stress( layer, kx, uz, ux, zeta )

global model

  % find all strain components due to uz and ux

  [ e_uz, e_ux ] = strain( layer, kx, uz, ux );		

  s_uz = stress_strain(layer, e_uz);
  s_ux = stress_strain(layer, e_ux);

  % if parameter zeta is given, replace the polynomial coefficients with values at 'zeta'

  if nargin >= 5

	vz = zeros(size(s_uz,1),1);
	vx = vz;

%s_uz
%zeta

	for i=1:size(s_uz,1)
		vz(i,1) = polyval(s_uz(i,:),zeta);
		vx(i,1) = polyval(s_ux(i,:),zeta);
	end

	s_uz = vz;
	s_ux = vx;
  end

end

