% Stress-strain relation (Hooke's law, optionally with viscosity)
%
% Parameters:
%	layer - layer number for which calculation is performed
%	strain - strain tensor, given by polynomial coefficients (rows).
%		Three rows of this matrix correspond to zz, xz, and xx components
%		of strain
%
% Returns:
%	stress - polynomial coefficients of the components of stress 
 
function stress = stress_strain( layer, strain, strain_rate )

global model

  del = strain(1,:) + strain(3,:);		% dilatational strain

  stress = strain*2*model.mu(layer,1);

  stress([1,3],:) = stress([1,3],:) + del*model.lambda(layer,1);
 
	% if strain_rate is given, add viscous stress

  if nargin > 2		

  	del = strain_rate(1,:) + strain_rate(3,:);	% dilatational strain rate

  	stress = stress + strain_rate*2*model.visc_mu(layer,1);

  	stress([1,3],:) = stress([1,3],:) + del*model.visc_lambda(layer,1);
  end

end

