%%%%%%%%%% P-SV wave modeling and inversion in a layered medium
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear

% You can keep several (optional) versions of the model .
% Edit, for example, 'model_2' and keep other models for comparison

% Columns of these matrices are:
%	1) depth to the bottom of layer (m)
%	2) density
%	3) P-wave velocity (m/ms or km/s)
%	4) S-wave velocity
%	5) bulk viscosity
%	6) shear viscosity

model_1 = [
	0.5	1.53	0.188	0.094	0.0	0.0		
	2.0	1.53	0.2	0.1	0.0	0.0			
	5.0	1.13	0.23	0.115	0.0	0.0	
	8.0	1.13	0.238	0.119	0.0	0.0	
	15.0	1.13	0.3	0.15	0.0	0.0	
	35.0	1.53	0.3	0.15	0.0	0.0
];

model_2 = [
	0.5,	1.53,	0.192,	0.096,	0.0,	0.0		
	2.0,	1.53,	0.222,	0.111,	0.0,	0.0			
	5.0,	1.13,	0.232,	0.116,	0.0,	0.0	
	8.0,	1.13,	0.242,	0.121,	0.0,	0.0	
	15.0,	1.13,	0.3,	0.15,	0.0,	0.0	
	35.0,	1.53,	0.3,	0.15,	0.0,	0.0
];

% several global variables for data exchange between functions and interactive inspection
 
global model bfun freq vphase vgroup

% Set up global 'model' using one of the velocity-density columns above:

set_model(model_2);

lambda2 = [ 0.5 : 0.25 : 20 ];	

% Model phase and group velocities at wavenumbers corresponding to lambda2:

[ freq, vphase, vgroup ] = modes_rayleigh( pi*lambda2.^(-1) );

figure(101)
clf
plot_model_modes( freq, vphase, [], 101 )

scale_model(1.25)

[ freq, vphase, vgroup ] = modes_rayleigh( pi*lambda2.^(-1) );

plot_model_modes( freq, vphase, [], 101 )

