%% Calculates group velocity from a frequency-dependent phase velocity

%% Parameters:
%%	freq - array of frequencies at which 'c' is given and 'U' is output
%%	c - array of phase velocities at 'freq'
%%
%% Return values:
%%	U - group velocities, formatted as 'freq' and 'c'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function U = vel_group(freq,c)

  % will use relation: U = c + k*d(c)/dk

  k = freq./c*2*pi;

  % find derivatives by using polynomial functions

  dcdk = zeros(size(c));

  n = length(c)-1;

  for i=2:n

	% parabolic fit at point i

	p = polyfit(k((i-1):(i+1)),c((i-1):(i+1)),2);

	p = polyder(p);

	dcdk(i) = polyval(p,k(i));

	% extend to ends

	if i==2
		 dcdk(1) = polyval(p,k(1));
	end

	if i==n
		 dcdk(end) = polyval(p,k(end));
	end
  end

  U = c + k.*dcdk;

end

