%% This function is for performing iterative inversion by using function 'fminsearh'.
%% It scales the model velocities by  
%% Returns the misfit between 'data' fields in global structure 'inversion' 
%% and modeled 
%% -------------------------------------------------------------------------
%%
%% Return value:
%%	Phi - misfit value
%% =========================================================================

function Phi = vphase_misfit_rayleigh(par)

global model inversion

  % restrict 'par' values to reasonable values

  parmin = 0.5;		% range of allowed values for par
  parmax = 2.0;

  ind = find(par < parmin);

  if ~isempty(par)
	par(ind) = parmin;
  end

  ind = find(par > parmax);

  if ~isempty(par)
	par(ind) = parmax;
  end

  % transform the model according to trial parameters 'par'

  scale_model(par);

  % model phase velocities

  [ freq, vphase ] = modes_rayleigh(inversion.kx);

  % return L1 phase-velocity misfit

  if isempty( inversion.data0 )
  	Phi = 0.0;
  else
	Phi = misfit_L1(inversion.data0, [freq(:,1), vphase(:,1) ]);
  end

  if ~isempty( inversion.data1 )
	Phi = Phi + misfit_L1(inversion.data1, [freq(:,2), vphase(:,2) ]);
  end

  if ~isempty( inversion.data2 )
	Phi = Phi + misfit_L1(inversion.data2, [freq(:,3), vphase(:,3) ]);
  end

%Phi

  % plot current best-fit model

  if Phi < inversion.Phi_best

	inversion.Phi_best = Phi;

	figure(777)
	clf
	plot_model()

	title(sprintf('Inversion misfit = %1.3f',Phi))
  end


end

